########################################################################################################
#########################################################################################################
######################### Predict Timing of the First Post-Conflict Election ###########################
#########################################################################################################
########################################################################################################

library(foreign)
library(splines)
library(survival)
library(xtable)
data <-read.dta("/Users/brancati/Documents/Working Papers/Active/Election Timing/Analysis/REPLICATION FILES/DATA/BS09_DATA_main.dta")
attach(data)

#########################################################################################################
#########################################################################################################
######################### Variance-Corrected (Gap Time), No Frailty, No Strata ##########################
#########################################################################################################
#########################################################################################################

###################################
### FIRST POST-CONFLICT ELECTIONS##
###################################

##################################
## INTERNATIONAL CONSIDERATIONS ##
##################################

FPEmodel1 <- coxph(Surv(T2fpemths1,fEND1)~fintvngwar1+postCW+unintrvnALL+UNfpeaid1+cluster(countryname), method=c("efron"),data=data)
summary(FPEmodel1)
    #TEST OF PROPORTIONALITY# 
    FPEmodel1.table1 <- cox.zph(FPEmodel1)
    print(FPEmodel1.table1)

FPEmodel2 <- coxph(Surv(T2fpemths1,fEND1)~fintvngwar1+postCW+unintrvnALL+UNaidfpeTECH1+cluster(countryname), method=c("efron"),data=data)
summary(FPEmodel2)
    #TEST OF PROPORTIONALITY# 
    FPEmodel2.table1 <- cox.zph(FPEmodel2)
    print(FPEmodel1.table1)

FPEmodel1a <- coxph(Surv(T2fpemths1,fEND1)~fintvngwar1+postCW+unintrvnALL+UNfpeaid1+USak110fpedate1+cluster(countryname), method=c("efron"),data=data)
summary(FPEmodel1a)
    #TEST OF PROPORTIONALITY# 
    FPEmodel1a.table1a <- cox.zph(FPEmodel1a)
    print(FPEmodel1a.table1a)
    
############################
# DOMESTIC CONSIDERATIONS  #
############################  

FPEmodel3 <-coxph(Surv(T2fpemths1,fEND1)~fintvngwar1+postCW+unintrvnALL+UNfpeaid1+victory+cycle+prv10yrs+prop+mixed+unexec+dcen+cluster(countryname), method=c("efron"),data=data)
summary(FPEmodel3)
   #TEST OF PROPORTIONALITY# 
    FPEmodel3.table1 <- cox.zph(FPEmodel3)
    print(FPEmodel3.table1)

FPEmodel4 <- coxph(Surv(T2fpemths1,fEND1)~fintvngwar1+postCW+unintrvnALL+UNfpeaid1+rebwin+govwin+cycle+prv10yrs+prop+mixed+unexec+dcen+cluster(countryname), method=c("efron"),data=data)
summary(FPEmodel4)
   #TEST OF PROPORTIONALITY# 
    FPEmodel4.table1 <- cox.zph(FPEmodel4)
    print(FPEmodel4.table1)


VICunintrvnALL <- victory*unintrvnALL    
FPEmodel5 <- coxph(Surv(T2fpemths1,fEND1)~fintvngwar1+postCW+unintrvnALL+UNfpeaid1+victory+VICunintrvnALL+cycle+prv10yrs+prop+mixed+unexec+dcen+cluster(countryname), method=c("efron"),data=data)
summary(FPEmodel5)
   #TEST OF PROPORTIONALITY# 
    FPEmodel5.table1 <- cox.zph(FPEmodel5)
    print(FPEmodel5.table1)

########################## 
# INSTITUTIONAL CAPACITY #
########################## 

FPEmodel6 <- coxph(Surv(T2fpemths1,fEND1)~fintvngwar1+postCW+unintrvnALL+UNfpeaid1+victory+cycle+prv10yrs+prop+mixed+unexec+dcen+gdpend+wardur+dead+ridp+cluster(countryname), method=c("efron"),data=data)
summary(FPEmodel6)
   #TEST OF PROPORTIONALITY# 
    FPEmodel6.table1 <- cox.zph(FPEmodel6)
    print(FPEmodel6.table1)    

FPEmodel7 <- coxph(Surv(T2fpemths1,fEND1)~fintvngwar1+postCW+unintrvnALL+UNfpeaid1+victory+cycle+prv10yrs+prop+mixed+unexec+dcen+FPEelectricity1+cluster(countryname), method=c("efron"),data=data)
summary(FPEmodel7)
   #TEST OF PROPORTIONALITY# 
    FPEmodel7.table1 <- cox.zph(FPEmodel7)
    print(FPEmodel7.table1)   
    
FPEmodel8 <- coxph(Surv(T2fpemths1,fEND1)~fintvngwar1+postCW+unintrvnALL+UNfpeaid1+victory+cycle+prv10yrs+prop+mixed+unexec+dcen+FPEpavedroads1+cluster(countryname), method=c("efron"),data=data)
summary(FPEmodel8)
   #TEST OF PROPORTIONALITY# 
    FPEmodel8.table1 <- cox.zph(FPEmodel8)
    print(FPEmodel8.table1)       

############################################
###FIRST POST-CONFLICT NATIONAL ELECTIONS###
############################################

##################################
## INTERNATIONAL CONSIDERATIONS ##
##################################

NEmodel1 <- coxph(Surv(T2nemths1,nEND1)~nintvngwar1+postCW+unintrvnALL+UNneaid1+cluster(countryname), method=c("efron"),data=data)
summary(NEmodel1)
    #TEST OF PROPORTIONALITY# 
    NEmodel1.table1 <- cox.zph(NEmodel1)
    print(NEmodel1.table1)

NEmodel2 <- coxph(Surv(T2nemths1,nEND1)~nintvngwar1+postCW+unintrvnALL+UNaidneTECH1+cluster(countryname), method=c("efron"),data=data)
summary(NEmodel2)
    #TEST OF PROPORTIONALITY# 
    NEmodel2.table1 <- cox.zph(NEmodel2)
    print(NEmodel1.table1)
    
NEmodel1a <- coxph(Surv(T2nemths1,nEND1)~nintvngwar1+postCW+unintrvnALL+UNneaid1+USak110nedate1+cluster(countryname), method=c("efron"),data=data)
summary(NEmodel1a)
    #TEST OF PROPORTIONALITY# 
    NEmodel1.table1a <- cox.zph(NEmodel1a)
    print(NEmodel1.table1a)    

############################
# DOMESTIC CONSIDERATIONS  #
############################  

NEmodel3 <- coxph(Surv(T2nemths1,nEND1)~nintvngwar1+postCW+unintrvnALL+UNneaid1+victory+cycle+prv10yrs+prop+mixed+unexec+dcen+cluster(countryname), method=c("efron"),data=data)
summary(NEmodel3)
   #TEST OF PROPORTIONALITY# 
    NEmodel3.table1 <- cox.zph(NEmodel3)
    print(NEmodel3.table1)

NEmodel4 <- coxph(Surv(T2nemths1,nEND1)~nintvngwar1+postCW+unintrvnALL+UNneaid1+rebwin+govwin+cycle+prv10yrs+prop+mixed+unexec+dcen+cluster(countryname), method=c("efron"),data=data)
summary(NEmodel4)
   #TEST OF PROPORTIONALITY# 
    NEmodel4.table1 <- cox.zph(NEmodel4)
    print(NEmodel4.table1)

VICunintrvnALL <- victory*unintrvnALL     
NEmodel5 <- coxph(Surv(T2nemths1,nEND1)~nintvngwar1+postCW+unintrvnALL+UNneaid1+victory+VICunintrvnALL+cycle+prv10yrs+prop+mixed+unexec+dcen+cluster(countryname), method=c("efron"),data=data)
summary(NEmodel5)
   #TEST OF PROPORTIONALITY# 
    NEmodel5.table1 <- cox.zph(NEmodel5)
    print(NEmodel5.table1)    
    
########################## 
# INSTITUTIONAL CAPACITY #
########################## 

NEmodel6 <- coxph(Surv(T2nemths1,nEND1)~nintvngwar1+postCW+unintrvnALL+UNneaid1+victory+cycle+prv10yrs+prop+mixed+unexec+dcen+gdpend+wardur+dead+ridp+cluster(countryname), method=c("efron"),data=data)
summary(NEmodel6)
   #TEST OF PROPORTIONALITY# 
    NEmodel6.table1 <- cox.zph(NEmodel6)
    print(NEmodel6.table1)    

NEmodel7 <- coxph(Surv(T2nemths1,nEND1)~nintvngwar1+postCW+unintrvnALL+UNneaid1+victory+cycle+prv10yrs+prop+mixed+unexec+ +dcen+NEelectricity1+dcen+cluster(countryname), method=c("efron"),data=data)
summary(NEmodel7)
   #TEST OF PROPORTIONALITY# 
    NEmodel7.table1 <- cox.zph(NEmodel7)
    print(NEmodel7.table1)   
    
NEmodel8 <- coxph(Surv(T2nemths1,nEND1)~nintvngwar1+postCW+unintrvnALL+UNneaid1+victory+cycle+prv10yrs+prop+mixed+unexec+dcen+NEpavedroads1+cluster(countryname), method=c("efron"),data=data)
summary(NEmodel8)
   #TEST OF PROPORTIONALITY# 
    NEmodel8.table1 <- cox.zph(NEmodel8)
    print(NEmodel8.table1) 

#########################################################################################################
#########################################################################################################
##################################Conditional Cox Model in Gap Time  ####################################
#########################################################################################################
#########################################################################################################

# eventno=1. Strata with few events (i,e., 6 & 7 events) have been combined. It is harder to converge without combining. 

###################################
### FIRST POST-CONFLICT ELECTIONS##
###################################
###################################
## INTERNATIONAL CONSIDERATIONS ###
###################################

FPEmodel1cg <- coxph(Surv(T2fpemths1,fEND1)~fintvngwar1+postCW+unintrvnALL+UNfpeaid1+cluster(countryname) + strata(eventno1), method=c("efron"),data=data)
summary(FPEmodel1cg)

FPEcond.gap.surv1 <- survfit(FPEmodel1cg)
summary (FPEcond.gap.surv1)

### Plot Cumulative Hazards for Each Strata ####

plot(FPEcond.gap.surv1,fun="cumhaz",lty=c(1,2,3,4,5,6,7),col=c("black","black","black","black","black", "black","black"),lwd=c(1,1,2,2,2,2,2),ylab="Cumulative Hazard",xlab="Time (Years)",ylim=c(0,4))
leg.txt <- c("Event 1","Event 2","Event 3","Event 4","Event 5", "Event 6", "Event 7")
legend(5,4.0,leg.txt,lty=c(1,2,3,4,5,6,7),col=c("black","black","black","black","black","black","black"),lwd=c(1,1,2,2,2,2,2))
temp <- c(1,2,3,4,5,6,7,8)
axis(1,temp)


FPEmodel2cg <- coxph(Surv(T2fpemths1,fEND1)~fintvngwar1+postCW+unintrvnALL+UNaidfpeTECH1+cluster(countryname) + strata(eventno1), method=c("efron"),data=data)
summary(FPEmodel2cg)

FPEcond.gap.surv2 <- survfit(FPEmodel2cg)
summary (FPEcond.gap.surv2)

### Plot Cumulative Hazards for Each Strata ####

plot(FPEcond.gap.surv2,fun="cumhaz",lty=c(1,2,3,4,5,6,7),col=c("black","black","black","black","black", "black","black"),lwd=c(1,1,2,2,2,2,2),ylab="Cumulative Hazard",xlab="Time (Years)",ylim=c(0,4))
leg.txt <- c("Event 1","Event 2","Event 3","Event 4","Event 5", "Event 6", "Event 7")
legend(5,4.0,leg.txt,lty=c(1,2,3,4,5,6,7),col=c("black","black","black","black","black","black","black"),lwd=c(1,1,2,2,2,2,2))
temp <- c(1,2,3,4,5,6,7,8)
axis(1,temp)



FPEmodel3cg <- coxph(Surv(T2fpemths1,fEND1)~fintvngwar1+postCW+unintrvnALL+UNaidfpeTECH1+cluster(countryname) + strata(eventno1), method=c("efron"),data=data)
summary(FPEmodel2cg)

FPEcond.gap.surv3 <- survfit(FPEmodel3cg)
summary (FPEcond.gap.surv3)

### Plot Cumulative Hazards for Each Strata ####

plot(FPEcond.gap.surv3,fun="cumhaz",lty=c(1,2,3,4,5,6,7),col=c("black","black","black","black","black", "black","black"),lwd=c(1,1,2,2,2,2,2),ylab="Cumulative Hazard",xlab="Time (Years)",ylim=c(0,4))
leg.txt <- c("Event 1","Event 2","Event 3","Event 4","Event 5", "Event 6", "Event 7")
legend(5,4.0,leg.txt,lty=c(1,2,3,4,5,6,7),col=c("black","black","black","black","black","black","black"),lwd=c(1,1,2,2,2,2,2))
temp <- c(1,2,3,4,5,6,7,8)
axis(1,temp)


############################
# DOMESTIC CONSIDERATIONS  #
############################  

FPEmodel4cg <- coxph(Surv(T2fpemths1,fEND1)~fintvngwar1+postCW+unintrvnALL+UNfpeaid1+victory+cycle+prv10yrs+prop+mixed+unexec+dcen+cluster(countryname) + strata(eventno1), method=c("efron"),data=data)
summary(FPEmodel4cg)

FPEcond.gap.surv4 <- survfit(FPEmodel4cg)
summary (FPEcond.gap.surv4)

### Plot Cumulative Hazards for Each Strata ####

plot(FPEcond.gap.surv4,fun="cumhaz",lty=c(1,2,3,4,5,6,7),col=c("black","black","black","black","black", "black","black"),lwd=c(1,1,2,2,2,2,2),ylab="Cumulative Hazard",xlab="Time (Years)",ylim=c(0,4))
leg.txt <- c("Event 1","Event 2","Event 3","Event 4","Event 5", "Event 6", "Event 7")
legend(5,4.0,leg.txt,lty=c(1,2,3,4,5,6,7),col=c("black","black","black","black","black","black","black"),lwd=c(1,1,2,2,2,2,2))
temp <- c(1,2,3,4,5,6,7,8)
axis(1,temp)


FPEmodel5cg <- coxph(Surv(T2fpemths1,fEND1)~fintvngwar1+postCW+unintrvnALL+UNfpeaid1+rebwin+govwin+cycle+prv10yrs+prop+mixed+unexec+dcen+cluster(countryname) + strata(eventno1), method=c("efron"),data=data)
summary(FPEmodel5cg)

FPEcond.gap.surv5 <- survfit(FPEmodel5cg)
summary (FPEcond.gap.surv5)

### Plot Cumulative Hazards for Each Strata ####

plot(FPEcond.gap.surv5,fun="cumhaz",lty=c(1,2,3,4,5,6,7),col=c("black","black","black","black","black", "black","black"),lwd=c(1,1,2,2,2,2,2),ylab="Cumulative Hazard",xlab="Time (Years)",ylim=c(0,4))
leg.txt <- c("Event 1","Event 2","Event 3","Event 4","Event 5", "Event 6", "Event 7")
legend(5,4.0,leg.txt,lty=c(1,2,3,4,5,6,7),col=c("black","black","black","black","black","black","black"),lwd=c(1,1,2,2,2,2,2))
temp <- c(1,2,3,4,5,6,7,8)
axis(1,temp)

VICunintrvnALL <- victory*unintrvnALL
FPEmodel6cg <- coxph(Surv(T2fpemths1,fEND1)~fintvngwar1+postCW+unintrvnALL+UNfpeaid1+victory+VICunintrvnALL+cycle+prv10yrs+prop+mixed+unexec+dcen+cluster(countryname) + strata(eventno1), method=c("efron"),data=data)
summary(FPEmodel6cg)

FPEcond.gap.surv6 <- survfit(FPEmodel6cg)
summary (FPEcond.gap.surv6)

### Plot Cumulative Hazards for Each Strata ####

plot(FPEcond.gap.surv6,fun="cumhaz",lty=c(1,2,3,4,5,6,7),col=c("black","black","black","black","black", "black","black"),lwd=c(1,1,2,2,2,2,2),ylab="Cumulative Hazard",xlab="Time (Years)",ylim=c(0,4))
leg.txt <- c("Event 1","Event 2","Event 3","Event 4","Event 5", "Event 6", "Event 7")
legend(5,4.0,leg.txt,lty=c(1,2,3,4,5,6,7),col=c("black","black","black","black","black","black","black"),lwd=c(1,1,2,2,2,2,2))
temp <- c(1,2,3,4,5,6,7,8)
axis(1,temp)


########################## 
# INSTITUTIONAL CAPACITY #
########################## 

FPEmodel7cg <- coxph(Surv(T2fpemths1,fEND1)~fintvngwar1+postCW+unintrvnALL+UNfpeaid1+victory+cycle+prv10yrs+prop+mixed+unexec+dcen+gdpend+wardur+dead+ridp+cluster(countryname) + strata(eventno1), method=c("efron"),data=data)
summary(FPEmodel7cg)

#Model does not converge#

FPEmodel8cg <- coxph(Surv(T2fpemths1,fEND1)~fintvngwar1+postCW+unintrvnALL+UNfpeaid1+victory+cycle+prv10yrs+prop+mixed+unexec+dcen+FPEelectricity1+cluster(countryname) + strata(eventno1), method=c("efron"),data=data)
summary(FPEmodel8cg)

FPEcond.gap.surv8 <- survfit(FPEmodel8cg)
summary (FPEcond.gap.surv8)

### Plot Cumulative Hazards for Each Strata ####

plot(FPEcond.gap.surv8,fun="cumhaz",lty=c(1,2,3,4,5,6,7),col=c("black","black","black","black","black", "black","black"),lwd=c(1,1,2,2,2,2,2),ylab="Cumulative Hazard",xlab="Time (Years)",ylim=c(0,4))
leg.txt <- c("Event 1","Event 2","Event 3","Event 4","Event 5", "Event 6", "Event 7")
legend(5,4.0,leg.txt,lty=c(1,2,3,4,5,6,7),col=c("black","black","black","black","black","black","black"),lwd=c(1,1,2,2,2,2,2))
temp <- c(1,2,3,4,5,6,7,8)
axis(1,temp)


FPEmodel9cg <- coxph(Surv(T2fpemths1,fEND1)~fintvngwar1+postCW+unintrvnALL+UNfpeaid1+victory+cycle+prv10yrs+prop+mixed+unexec+dcen+FPEpavedroads1+cluster(countryname) + strata(eventno1), method=c("efron"),data=data)
summary(FPEmodel9cg)

FPEcond.gap.surv9 <- survfit(FPEmodel9cg)
summary (FPEcond.gap.surv9)

### Plot Cumulative Hazards for Each Strata ####

plot(FPEcond.gap.surv9,fun="cumhaz",lty=c(1,2,3,4,5,6,7),col=c("black","black","black","black","black", "black","black"),lwd=c(1,1,2,2,2,2,2),ylab="Cumulative Hazard",xlab="Time (Years)",ylim=c(0,4))
leg.txt <- c("Event 1","Event 2","Event 3","Event 4","Event 5", "Event 6", "Event 7")
legend(5,4.0,leg.txt,lty=c(1,2,3,4,5,6,7),col=c("black","black","black","black","black","black","black"),lwd=c(1,1,2,2,2,2,2))
temp <- c(1,2,3,4,5,6,7,8)
axis(1,temp)

############################################
###FIRST POST-CONFLICT NATIONAL ELECTIONS###
############################################

###################################
## INTERNATIONAL CONSIDERATIONS ###
###################################

NEmodel1cg <- coxph(Surv(T2nemths1,nEND1)~nintvngwar1+postCW+unintrvnALL+UNneaid1+cluster(countryname) + strata(eventno2), method=c("efron"),data=data)
summary(NEmodel1cg)

NEcond.gap.surv1 <- survfit(NEmodel1cg)
summary (NEcond.gap.surv1)

### Plot Cumulative Hazards for Each Strata ####

plot(NEcond.gap.surv1,fun="cumhaz",lty=c(1,2,3,4,5,6,7),col=c("black","black","black","black","black", "black","black"),lwd=c(1,1,2,2,2,2,2),ylab="Cumulative Hazard",xlab="Time (Years)",ylim=c(0,4))
leg.txt <- c("Event 1","Event 2","Event 3","Event 4","Event 5", "Event 6", "Event 7")
legend(5,4.0,leg.txt,lty=c(1,2,3,4,5,6,7),col=c("black","black","black","black","black","black","black"),lwd=c(1,1,2,2,2,2,2))
temp <- c(1,2,3,4,5,6,7,8)
axis(1,temp)


NEmodel2cg <- coxph(Surv(T2nemths1,nEND1)~nintvngwar1+postCW+unintrvnALL+UNaidneTECH1+cluster(countryname) + strata(eventno2), method=c("efron"),data=data)
summary(NEmodel2cg)

NEcond.gap.surv2 <- survfit(NEmodel2cg)
summary (NEcond.gap.surv2)

### Plot Cumulative Hazards for Each Strata ####

plot(NEcond.gap.surv2,fun="cumhaz",lty=c(1,2,3,4,5,6,7),col=c("black","black","black","black","black", "black","black"),lwd=c(1,1,2,2,2,2,2),ylab="Cumulative Hazard",xlab="Time (Years)",ylim=c(0,4))
leg.txt <- c("Event 1","Event 2","Event 3","Event 4","Event 5", "Event 6", "Event 7")
legend(5,4.0,leg.txt,lty=c(1,2,3,4,5,6,7),col=c("black","black","black","black","black","black","black"),lwd=c(1,1,2,2,2,2,2))
temp <- c(1,2,3,4,5,6,7,8)
axis(1,temp)


NEmodel3cg <- coxph(Surv(T2nemths1,nEND1)~nintvngwar1+postCW+unintrvnALL+UNneaid1+USak110nedate1+cluster(countryname) + strata(eventno2), method=c("efron"),data=data)
summary(NEmodel3cg)

NEcond.gap.surv3 <- survfit(NEmodel3cg)
summary (NEcond.gap.surv3)

### Plot Cumulative Hazards for Each Strata ####

plot(NEcond.gap.surv3,fun="cumhaz",lty=c(1,2,3,4,5,6,7),col=c("black","black","black","black","black", "black","black"),lwd=c(1,1,2,2,2,2,2),ylab="Cumulative Hazard",xlab="Time (Years)",ylim=c(0,4))
leg.txt <- c("Event 1","Event 2","Event 3","Event 4","Event 5", "Event 6", "Event 7")
legend(5,4.0,leg.txt,lty=c(1,2,3,4,5,6,7),col=c("black","black","black","black","black","black","black"),lwd=c(1,1,2,2,2,2,2))
temp <- c(1,2,3,4,5,6,7,8)
axis(1,temp)

############################
# DOMESTIC CONSIDERATIONS  #
############################  

NEmodel4cg <- coxph(Surv(T2nemths1,nEND1)~nintvngwar1+postCW+unintrvnALL+UNneaid1+victory+cycle+prv10yrs+prop+mixed+unexec+dcen+cluster(countryname) + strata(eventno2), method=c("efron"),data=data)
summary(NEmodel4cg)

cond.gap.surv4 <- survfit(NEmodel4cg)
summary (cond.gap.surv4)

### Plot Cumulative Hazards for Each Strata ####

plot(cond.gap.surv4,fun="cumhaz",lty=c(1,2,3,4,5,6,7),col=c("black","black","black","black","black", "black","black"),lwd=c(1,1,2,2,2,2,2),ylab="Cumulative Hazard",xlab="Time (Years)",ylim=c(0,4))
leg.txt <- c("Event 1","Event 2","Event 3","Event 4","Event 5", "Event 6", "Event 7")
legend(5,4.0,leg.txt,lty=c(1,2,3,4,5,6,7),col=c("black","black","black","black","black","black","black"),lwd=c(1,1,2,2,2,2,2))
temp <- c(1,2,3,4,5,6,7,8)
axis(1,temp)

NEmodel5cg <- coxph(Surv(T2nemths1,nEND1)~nintvngwar1+postCW+unintrvnALL+UNneaid1+rebwin+govwin+cycle+prv10yrs+prop+mixed+unexec+dcen+cluster(countryname) + strata(eventno2), method=c("efron"),data=data)
summary(FPEmodel5cg)

NEcond.gap.surv5 <- survfit(NEmodel5cg)
summary (NEcond.gap.surv5)

### Plot Cumulative Hazards for Each Strata ####

plot(NEcond.gap.surv5,fun="cumhaz",lty=c(1,2,3,4,5,6,7),col=c("black","black","black","black","black", "black","black"),lwd=c(1,1,2,2,2,2,2),ylab="Cumulative Hazard",xlab="Time (Years)",ylim=c(0,4))
leg.txt <- c("Event 1","Event 2","Event 3","Event 4","Event 5", "Event 6", "Event 7")
legend(5,4.0,leg.txt,lty=c(1,2,3,4,5,6,7),col=c("black","black","black","black","black","black","black"),lwd=c(1,1,2,2,2,2,2))
temp <- c(1,2,3,4,5,6,7,8)
axis(1,temp)

NEmodel6cg <- coxph(Surv(T2nemths1,nEND1)~nintvngwar1+postCW+unintrvnALL+UNneaid1+victory+VICunintrvnALL+cycle+prv10yrs+prop+mixed+unexec+dcen+cluster(countryname) + strata(eventno2), method=c("efron"),data=data)
summary(NEmodel6cg)

NEcond.gap.surv6 <- survfit(NEmodel6cg)
summary (NEcond.gap.surv6)

### Plot Cumulative Hazards for Each Strata ####

plot(NEcond.gap.surv6,fun="cumhaz",lty=c(1,2,3,4,5,6,7),col=c("black","black","black","black","black", "black","black"),lwd=c(1,1,2,2,2,2,2),ylab="Cumulative Hazard",xlab="Time (Years)",ylim=c(0,4))
leg.txt <- c("Event 1","Event 2","Event 3","Event 4","Event 5", "Event 6", "Event 7")
legend(5,4.0,leg.txt,lty=c(1,2,3,4,5,6,7),col=c("black","black","black","black","black","black","black"),lwd=c(1,1,2,2,2,2,2))
temp <- c(1,2,3,4,5,6,7,8)
axis(1,temp)


########################## 
# INSTITUTIONAL CAPACITY #
########################## 

NEmodel7cg <- coxph(Surv(T2nemths1,nEND1)~nintvngwar1+postCW+unintrvnALL+UNneaid1+victory+cycle+prv10yrs+prop+mixed+unexec+dcen+gdpend+wardur+dead+ridp+cluster(countryname) + strata(eventno2), method=c("efron"),data=data)
summary(NEmodel7cg)

# Model does not converge#

NEmodel8cg <- coxph(Surv(T2nemths1,nEND1)~nintvngwar1+postCW+unintrvnALL+UNneaid1+victory+cycle+prv10yrs+prop+mixed+unexec+dcen+NEelectricity1+cluster(countryname) + strata(eventno2), method=c("efron"),data=data)
summary(NEmodel8cg)

NEcond.gap.surv8 <- survfit(NEmodel8cg)
summary (NEcond.gap.surv8)

### Plot Cumulative Hazards for Each Strata ####

plot(NEcond.gap.surv8,fun="cumhaz",lty=c(1,2,3,4,5,6,7),col=c("black","black","black","black","black", "black","black"),lwd=c(1,1,2,2,2,2,2),ylab="Cumulative Hazard",xlab="Time (Years)",ylim=c(0,4))
leg.txt <- c("Event 1","Event 2","Event 3","Event 4","Event 5", "Event 6", "Event 7")
legend(5,4.0,leg.txt,lty=c(1,2,3,4,5,6,7),col=c("black","black","black","black","black","black","black"),lwd=c(1,1,2,2,2,2,2))
temp <- c(1,2,3,4,5,6,7,8)
axis(1,temp)


NEmodel9cg <- coxph(Surv(T2nemths1,nEND1)~nintvngwar1+postCW+unintrvnALL+UNneaid1+victory+cycle+prv10yrs+prop+mixed+unexec+dcen+NEpavedroads1+cluster(countryname) + strata(eventno2), method=c("efron"),data=data)
summary(NEmodel9cg)

NEcond.gap.surv9 <- survfit(NEmodel9cg)
summary (NEcond.gap.surv9)

### Plot Cumulative Hazards for Each Strata ####

plot(NEcond.gap.surv9,fun="cumhaz",lty=c(1,2,3,4,5,6,7),col=c("black","black","black","black","black", "black","black"),lwd=c(1,1,2,2,2,2,2),ylab="Cumulative Hazard",xlab="Time (Years)",ylim=c(0,4))
leg.txt <- c("Event 1","Event 2","Event 3","Event 4","Event 5", "Event 6", "Event 7")
legend(5,4.0,leg.txt,lty=c(1,2,3,4,5,6,7),col=c("black","black","black","black","black","black","black"),lwd=c(1,1,2,2,2,2,2))
temp <- c(1,2,3,4,5,6,7,8)
axis(1,temp)


########################################################################################################
########################################################################################################
################################# Frailty Models, No Strata ############################################
########################################################################################################
########################################################################################################

###################################
### FIRST POST-CONFLICT ELECTIONS##
###################################

##################################
## INTERNATIONAL CONSIDERATIONS ##
##################################

FPEmodel1f <- coxph(Surv(T2fpemths1,fEND1)~fintvngwar1+postCW+unintrvnALL+UNfpeaid1+frailty(countryname,distribution="gamma",method="em"), method=c("efron"),data=data)
summary(FPEmodel1f)
    #TEST OF PROPORTIONALITY# 
    FPEmodel1.table1f <- cox.zph(FPEmodelf1)
    print(FPEmodel1.table1f)

FPEmodel2f <- coxph(Surv(T2fpemths1,fEND1)~fintvngwar1+postCW+unintrvnALL+UNaidfpeTECH1+frailty(countryname,distribution="gamma",method="em"), method=c("efron"),data=data)
summary(FPEmodel2f)
    #TEST OF PROPORTIONALITY# 
    FPEmodel2.table1f <- cox.zph(FPEmodelf2)
    print(FPEmodel1.table1f)

FPEmodel1fa <- coxph(Surv(T2fpemths1,fEND1)~fintvngwar1+postCW+unintrvnALL+UNfpeaid1+USak110fpedate1+frailty(countryname,distribution="gamma",method="em"), method=c("efron"),data=data)
summary(FPEmodel1fa)
    #TEST OF PROPORTIONALITY# 
    FPEmodel1.table1fa <- cox.zph(FPEmodel1fa)
    print(FPEmodel1.table1fa)
        
############################
# DOMESTIC CONSIDERATIONS  #
############################  

FPEmodel3f <- coxph(Surv(T2fpemths1,fEND1)~fintvngwar1+postCW+unintrvnALL+UNfpeaid1+victory+cycle+prv10yrs+prop+mixed+unexec+dcen+frailty(countryname,distribution="gamma",method="em"), method=c("efron"),data=data)
summary(FPEmodel3f)
   #TEST OF PROPORTIONALITY# 
    FPEmodel3.table1f <- cox.zph(FPEmodel3f)
    print(FPEmodel3.table1f)

FPEmodel4f <- coxph(Surv(T2fpemths1,fEND1)~fintvngwar1+postCW+unintrvnALL+UNfpeaid1+rebwin+govwin+cycle+prv10yrs+prop+mixed+unexec+dcen+frailty(countryname,distribution="gamma",method="em"), method=c("efron"),data=data)
summary(FPEmodel4f)
   #TEST OF PROPORTIONALITY# 
    FPEmodel4.table1f <- cox.zph(FPEmodel4f)
    print(FPEmodel4.table1f)

VICunintrvnALL<-victory*unintrvnALL    
FPEmodel5f <- coxph(Surv(T2fpemths1,fEND1)~fintvngwar1+postCW+unintrvnALL+UNfpeaid1+victory+VICunintrvnALL+cycle+prv10yrs+prop+mixed+unexec+dcen+frailty(countryname,distribution="gamma",method="em"), method=c("efron"),data=data)
summary(FPEmodel5f)
   #TEST OF PROPORTIONALITY# 
    FPEmodel5.table1f <- cox.zph(FPEmodel5f)
    print(FPEmodel5.table1f)    
    
########################## 
# INSTITUTIONAL CAPACITY #
########################## 

FPEmodel6f <- coxph(Surv(T2fpemths1,fEND1)~fintvngwar1+postCW+unintrvnALL+UNfpeaid1+victory+cycle+prv10yrs+prop+mixed+unexec+dcen+gdpend+wardur+dead+ridp+frailty(countryname,distribution="gamma",method="em"), method=c("efron"),data=data)
summary(FPEmodel5f)
   #TEST OF PROPORTIONALITY# 
    FPEmodel6.table1f <- cox.zph(FPEmodel6f)
    print(FPEmodel6.table1f)    

FPEmodel7f <- coxph(Surv(T2fpemths1,fEND1)~fintvngwar1+postCW+unintrvnALL+UNfpeaid1+victory+cycle+prv10yrs+prop+mixed+unexec+ FPEelectricity1+dcen+frailty(countryname,distribution="gamma",method="em"), method=c("efron"),data=data)
summary(FPEmodel7f)
   #TEST OF PROPORTIONALITY# 
    FPEmodel7.table1f <- cox.zph(FPEmodel7f)
    print(FPEmodel7.table1f)   
    
FPEmodel8f <- coxph(Surv(T2fpemths1,fEND1)~fintvngwar1+postCW+unintrvnALL+UNfpeaid1+victory+cycle+prv10yrs+prop+mixed+unexec+FPEpavedroads1+frailty(countryname,distribution="gamma",method="em"), method=c("efron"),data=data)
summary(FPEmodel8f)
   #TEST OF PROPORTIONALITY# 
    FPEmodel8.table1f <- cox.zph(FPEmodel8f)
    print(FPEmodel8.table1f)       

############################################
###FIRST POST-CONFLICT NATIONAL ELECTIONS###
############################################

##################################
## INTERNATIONAL CONSIDERATIONS ##
##################################

NEmodel1f <- coxph(Surv(T2nemths1,nEND1)~nintvngwar1+postCW+unintrvnALL+UNneaid1+frailty(countryname,distribution="gamma",method="em"), method=c("efron"),data=data)
summary(NEmodel1f)
    #TEST OF PROPORTIONALITY# 
    NEmodel1.table1f <- cox.zph(NEmodel1f)
    print(NEmodel1.table1f)

NEmodel2f <- coxph(Surv(T2nemths1,nEND1)~nintvngwar1+postCW+unintrvnALL+UNaidneTECH1+frailty(countryname,distribution="gamma",method="em"), method=c("efron"),data=data)
summary(NEmodel2f)
    #TEST OF PROPORTIONALITY# 
    NEmodel2.table1f <- cox.zph(NEmodel2f)
    print(NEmodel1.table1f)
    
NEmodel1fa <- coxph(Surv(T2nemths1,nEND1)~nintvngwar1+postCW+unintrvnALL+UNneaid1+USak110nedate1+frailty(countryname,distribution="gamma",method="em"), method=c("efron"),data=data)
summary(NEmodel1fa)
    #TEST OF PROPORTIONALITY# 
    NEmodel1.table1fa <- cox.zph(NEmodel1fa)
    print(NEmodel1.table1fa)
        
############################
# DOMESTIC CONSIDERATIONS  #
############################  

NEmodel3f <- coxph(Surv(T2nemths1,nEND1)~nintvngwar1+postCW+unintrvnALL+UNneaid1+victory+cycle+prv10yrs+prop+mixed+unexec+dcen+frailty(countryname,distribution="gamma",method="em"), method=c("efron"),data=data)
summary(NEmodel3f)
   #TEST OF PROPORTIONALITY# 
    NEmodel3.table1f <- cox.zph(NEmodel3f)
    print(NEmodel3.table1f)

NEmodel4f <- coxph(Surv(T2nemths1,nEND1)~nintvngwar1+postCW+unintrvnALL+UNneaid1+rebwin+govwin+cycle+prv10yrs+prop+mixed+unexec+dcen+frailty(countryname,distribution="gamma",method="em"), method=c("efron"),data=data)
summary(NEmodel4f)
   #TEST OF PROPORTIONALITY# 
    FPEmodel4.table1f <- cox.zph(NEmodel4f)
    print(NEmodel4.table1f)

gen VICunintrvnALL = victory*unintrvnALL
    
NEmodel5f <- coxph(Surv(T2nemths1,nEND1)~nintvngwar1+postCW+unintrvnALL+UNneaid1+victory+VICunintrvnALL+cycle+prv10yrs+prop+mixed+unexec+dcen+frailty(countryname,distribution="gamma",method="em"), method=c("efron"),data=data)
summary(NEmodel5f)
   #TEST OF PROPORTIONALITY# 
    NEmodel5.table1f <- cox.zph(NEmodel5f)
    print(NEmodel5.table1f)    
    
########################## 
# INSTITUTIONAL CAPACITY #
########################## 

NEmodel6f <- coxph(Surv(T2nemths1,nEND1)~nintvngwar1+postCW+unintrvnALL+UNneaid1+victory+cycle+prv10yrs+prop+mixed+unexec+dcen+gdpend+wardur+dead+ridp+frailty(countryname,distribution="gamma",method="em"), method=c("efron"),data=data)
summary(FPEmodel5f)
   #TEST OF PROPORTIONALITY# 
    NEmodel6.table1f <- cox.zph(NEmodel6f)
    print(FPEmodel6.table1f)    

NEmodel7f <- coxph(Surv(T2nemths1,nEND1)~nintvngwar1+postCW+unintrvnALL+UNneaid1+victory+cycle+prv10yrs+prop+mixed+unexec+dcen+NEelectricity1++frailty(countryname,distribution="gamma",method="em"), method=c("efron"),data=data)
summary(NEmodel7f)
   #TEST OF PROPORTIONALITY# 
    NEmodel7.table1f <- cox.zph(NEmodel7f)
    print(FPEmodel7.table1f)   
    
NEmodel8f <- coxph(Surv(T2nemths1,nEND1)~nintvngwar1+postCW+unintrvnALL+UNneaid1+victory+cycle+prv10yrs+prop+mixed+unexec+dcen+NEpavedroads1+frailty(countryname,distribution="gamma",method="em"), method=c("efron"),data=data)
summary(NEmodel8f)
   #TEST OF PROPORTIONALITY# 
    NEmodel8.table1f <- cox.zph(NEmodel8f)
    print(NEmodel8.table1f) 

#################################################################################################################################################################################################################
################################## Conditional Frailty Models ###########################################
#########################################################################################################
########################################################################################################

###################################
### FIRST POST-CONFLICT ELECTIONS##
###################################

##################################
## INTERNATIONAL CONSIDERATIONS ##
##################################

FPEmodel1cf <- coxph(Surv(T2fpemths1,fEND1)~fintvngwar1+postCW+unintrvnALL+UNfpeaid1+strata(eventno2)+frailty(countryname,distribution="gamma",method="em"), method=c("efron"),data=data)
summary(FPEmodel1cf)
    #TEST OF PROPORTIONALITY# 
    FPEmodel1.table1cf <- cox.zph(FPEmodel1cf)
    print(FPEmodel1.table1cf)

FPEmodel2cf <- coxph(Surv(T2fpemths1,fEND1)~fintvngwar1+postCW+unintrvnALL+UNaidfpeTECH1+strata(eventno2)+frailty(countryname,distribution="gamma",method="em"), method=c("efron"),data=data)
summary(FPEmodel2cf)
    #TEST OF PROPORTIONALITY# 
    FPEmodel2.table1cf <- cox.zph(FPEmodel2cf)
    print(FPEmodel1.table1cf)

FPEmodel1cfa <- coxph(Surv(T2fpemths1,fEND1)~fintvngwar1+postCW+unintrvnALL+UNfpeaid1+USak110fpedate1+strata(eventno2)+frailty(countryname,distribution="gamma",method="em"), method=c("efron"),data=data)
summary(FPEmodel1cfa)
    #TEST OF PROPORTIONALITY# 
    #FPEmodel1.table1cfa <- cox.zph(FPEmodel1cfa)
    #print(FPEmodel1.table1cfa)
    
############################
# DOMESTIC CONSIDERATIONS  #
############################  

FPEmodel3cf <- coxph(Surv(T2fpemths1,fEND1)~fintvngwar1+postCW+unintrvnALL+UNfpeaid1+victory+cycle+prv10yrs+prop+mixed+unexec+dcen+strata(eventno2)+frailty(countryname,distribution="gamma",method="em"), method=c("efron"),data=data)
summary(FPEmodel3cf)
   #TEST OF PROPORTIONALITY# 
    FPEmodel3.table1cf <- cox.zph(FPEmodel3cf)
    print(FPEmodel3.table1cf)

FPEmodel4cf <- coxph(Surv(T2fpemths1,fEND1)~fintvngwar1+postCW+unintrvnALL+UNfpeaid1+rebwin+govwin+cycle+prv10yrs+prop+mixed+unexec+dcen+strata(eventno2)+frailty(countryname,distribution="gamma",method="em"), method=c("efron"),data=data)
summary(FPEmodel4cf)
   #TEST OF PROPORTIONALITY# 
    FPEmodel4.table1cf <- cox.zph(FPEmodel4cf)
    print(FPEmodel4.table1cf)

VICunintrvnALL <- victory*unintrvnALL
FPEmodel5cf <- coxph(Surv(T2fpemths1,fEND1)~fintvngwar1+postCW+unintrvnALL+UNfpeaid1+victory+VICunintrvnALL+cycle+prv10yrs+prop+mixed+unexec+dcen+strata(eventno2)+frailty(countryname,distribution="gamma",method="em"), method=c("efron"),data=data)
summary(FPEmodel5cf)
   #TEST OF PROPORTIONALITY# 
    FPEmodel5.table1cf <- cox.zph(FPEmodel5cf)
    print(FPEmodel5.table1cf)    
    
########################## 
# INSTITUTIONAL CAPACITY #
########################## 

FPEmodel6cf <- coxph(Surv(T2fpemths1,fEND1)~fintvngwar1+postCW+unintrvnALL+UNfpeaid1+victory+cycle+prv10yrs+prop+mixed+unexec+dcen+gdpend+wardur+dead+ridp+strata(eventno2)+frailty(countryname,distribution="gamma",method="em"), method=c("efron"),data=data)
summary(FPEmodel5cf)
   #TEST OF PROPORTIONALITY# 
    FPEmodel6.table1cf <- cox.zph(FPEmodel6cf)
    print(FPEmodel6.table1cf)    

FPEmodel7cf <- coxph(Surv(T2fpemths1,fEND1)~fintvngwar1+postCW+unintrvnALL+UNfpeaid1+victory+cycle+prv10yrs+prop+mixed+unexec+dcen+FPEelectricity1++strata(eventno2)+frailty(countryname,distribution="gamma",method="em"), method=c("efron"),data=data)
summary(FPEmodel7cf)
   #TEST OF PROPORTIONALITY# 
    FPEmodel7.table1cf <- cox.zph(FPEmodel7cf)
    print(FPEmodel7.table1cf)   
    
FPEmodel8cf <- coxph(Surv(T2fpemths1,fEND1)~fintvngwar1+postCW+unintrvnALL+UNfpeaid1+victory+cycle+prv10yrs+prop+mixed+unexec+dcen+FPEpavedroads1+strata(eventno2)+frailty(countryname,distribution="gamma",method="em"), method=c("efron"),data=data)
summary(FPEmodel8cf)
   #TEST OF PROPORTIONALITY# 
    FPEmodel8.table1cf <- cox.zph(FPEmodel8cf)
    print(FPEmodel8.table1cf)       

############################################
###FIRST POST-CONFLICT NATIONAL ELECTIONS###
############################################

##################################
## INTERNATIONAL CONSIDERATIONS ##
##################################

NEmodel1cf <- coxph(Surv(T2nemths1,nEND1)~nintvngwar1+postCW+unintrvnALL+UNneaid1+strata(eventno2)+frailty(countryname,distribution="gamma",method="em"), method=c("efron"),data=data)
summary(NEmodel1cf)
    #TEST OF PROPORTIONALITY# 
    NEmodel1.table1cf <- cox.zph(NEmodel1cf)
    print(NEmodel1.table1cf)

NEmodel2cf <- coxph(Surv(T2nemths1,nEND1)~nintvngwar1+postCW+unintrvnALL+UNaidneTECH1+strata(eventno2)+frailty(countryname,distribution="gamma",method="em"), method=c("efron"),data=data)
summary(NEmodel2cf)
    #TEST OF PROPORTIONALITY# 
    NEmodel2.table1cf <- cox.zph(NEmodel2cf)
    print(NEmodel1.table1cf)

NEmodel1cfa <- coxph(Surv(T2nemths1,nEND1)~nintvngwar1+postCW+unintrvnALL+UNneaid1+USak110nedate1+strata(eventno2)+frailty(countryname,distribution="gamma",method="em"), method=c("efron"),data=data)
summary(NEmodel1cfa)
    #TEST OF PROPORTIONALITY# 
    #NEmodel1.table1cfa <- cox.zph(NEmodel1cfa)
    #print(NEmodel1.table1cfa)
    
############################
# DOMESTIC CONSIDERATIONS  #
############################  

NEmodel3cf <- coxph(Surv(T2nemths1,nEND1)~nintvngwar1+postCW+unintrvnALL+UNneaid1+victory+cycle+prv10yrs+prop+mixed+unexec+dcen+strata(eventno2)+frailty(countryname,distribution="gamma",method="em"), method=c("efron"),data=data)
summary(NEmodel3cf)
   #TEST OF PROPORTIONALITY# 
    NEmodel3.table1cf <- cox.zph(NEmodel3cf)
    print(NEmodel3.table1cf)

NEmodel4cf <- coxph(Surv(T2nemths1,nEND1)~nintvngwar1+postCW+unintrvnALL+UNneaid1+rebwin+govwin+cycle+prv10yrs+prop+mixed+unexec+dcen+strata(eventno2)+frailty(countryname,distribution="gamma",method="em"), method=c("efron"),data=data)
summary(NEmodel4cf)
   #TEST OF PROPORTIONALITY# 
    FPEmodel4.table1cf <- cox.zph(NEmodel4cf)
    print(NEmodel4.table1cf)

gen VICunintrvnALL = victory*unintrvnALL
NEmodel5cf <- coxph(Surv(T2nemths1,nEND1)~nintvngwar1+postCW+unintrvnALL+UNneaid1+victory+VICunintrvnALL+cycle+prv10yrs+prop+mixed+unexec+dcen+strata(eventno2)+frailty(countryname,distribution="gamma",method="em"), method=c("efron"),data=data)
summary(NEmodel5cf)
   #TEST OF PROPORTIONALITY# 
    NEmodel5.table1cf <- cox.zph(NEmodel5cf)
    print(NEmodel5.table1cf)    
    
########################## 
# INSTITUTIONAL CAPACITY #
########################## 

NEmodel6cf <- coxph(Surv(T2nemths1,nEND1)~nintvngwar1+postCW+unintrvnALL+UNneaid1+victory+cycle+prv10yrs+prop+mixed+unexec+dcen+gdpend+wardur+dead+ridp+strata(eventno2)+frailty(countryname,distribution="gamma",method="em"), method=c("efron"),data=data)
summary(FPEmodel5cf)
   #TEST OF PROPORTIONALITY# 
    NEmodel6.table1cf <- cox.zph(NEmodel6cf)
    print(FPEmodel6.table1cf)    

NEmodel7cf <- coxph(Surv(T2nemths1,nEND1)~nintvngwar1+postCW+unintrvnALL+UNneaid1+victory+cycle+prv10yrs+prop+mixed+unexec+ NEelectricity1+dcen+strata(eventno2)+frailty(countryname,distribution="gamma",method="em"), method=c("efron"),data=data)
summary(NEmodel7cf)
   #TEST OF PROPORTIONALITY# 
    NEmodel7.table1cf <- cox.zph(NEmodel7cf)
    print(FPEmodel7.table1cf)   
    
NEmodel8cf <- coxph(Surv(T2nemths1,nEND1)~nintvngwar1+postCW+unintrvnALL+UNneaid1+victory+cycle+prv10yrs+prop+mixed+unexec+dcen++NEpavedroads1+strata(eventno2)+frailty(countryname,distribution="gamma",method="em"), method=c("efron"),data=data)
summary(NEmodel8cf)
   #TEST OF PROPORTIONALITY# 
    NEmodel8.table1cf <- cox.zph(NEmodel8cf)
    print(NEmodel8.table1cf) 

                           