********************************************************************
**iDOSERESPONSE CODE (MATCHING USING CONTINUOUS TREATMENT OF TIME)**
********************************************************************

*Note: The GPS formula is based on the probability density function of the normal distribution (see notes).  
*Note: If data is in years rather than months, predicted _hat treat is different.  GPS is the same, sd2 is the same. 


***************************************************************************************************************************************
********************************************* FIRST POST-CONFLICT ELECTIONS ***********************************************************
**************************************************  ALL ELECTIONS  ********************************************************************
***************************************************************************************************************************************

*************************************************
**GENERATE DATAFILE: BASIC MODEL + POWERSHARING**
*************************************************

*GENERATE DATAFILE: MISSING DATA NOT ALLOWED*
clear
use "/Users/brancati/Documents/Working Papers/Active/Election Timing/Analysis/REPLICATION FILES/DATA/BS09_DATA_main.dta"
keep if fENDinWAR !=1
keep cwid countryname nwar1 T2fpemths1 postCW victory cycle fintvngwar1 unintrvnALL UNfpeaid1 eventno2 prop mixed unexec dcen
drop if (T2fpemths1 == . | postCW  == . | victory == . |  cycle == . | fintvngwar1 == . | unintrvnALL == . | UNfpeaid1 == . | eventno2 == .| prop == . | mixed == . | unexec == . | dcen == .)
*save "/Users/brancati/Documents/Working Papers/Active/Election Timing/Analysis/REPLICATION FILES/DATA/BS09_iDOSERESPONSE_fpepower.dta", replace

*GENERATE CUT VARIABLE BASED ON THE TREATMENT*
sort countryname cwid
egen cutMTHS = cut(T2fpemths1), group(3)

*GENERATE CUT VARIABLE BASED ON THE TREATMENT (YEARS)*
sort countryname cwid
gen T2fpeyrs1 = T2fpemths1/12
egen cutYRS = cut(T2fpeyrs1), group(3)

*Note: While fintvngwar1 may be used to predict T2fpemths1, in the second analysis we drop all post-conflict periods for which an election does not not occur before a new civil war occurs. As a result, fintvngwar1 is equal to 0 in all cases. It is not included as a predictor of timing as a result. 
*CALCULATE GPS AND CHECK FOR BALANCE (MONTHS and YEARS)*
 gpscore postCW victory cycle unintrvnALL UNfpeaid1 eventno2 prop mixed unexec dcen, t(T2fpemths1) gpscore(pscore) predict(hat_treat) sigma(sd) cutpoints(cutMTHS) index(mean) nq_gps(3) t_transf(ln) detail
gpscore postCW victory cycle unintrvnALL UNfpeaid1 eventno2 prop mixed unexec dcen, t(T2fpeyrs1) gpscore(pscore) predict(hat_treat) sigma(sd) cutpoints(cutYRS) index(mean) nq_gps(3) t_transf(ln) detail
 #Satisfying property at .01 is weaker than at .10 level -- for the first (0.01) this means, that the treatment and controls are not significantly different is we use a 99 percent level of significance, but they are significantly different at the 95 percent level. 
 
Note:Balancing is satisfied at a higher level with different treatment groups. 
*sort countryname cwid
*gen T2fpeyrs1 = T2fpemths1/12
*egen cutYRS = cut(T2fpeyrs1), group(2)
 gpscore postCW victory cycle  unintrvnALL UNfpeaid1 eventno2 prop mixed unexec dcen, t(T2fpeyrs1) gpscore(pscore) predict(hat_treat) sigma(sd) cutpoints(cutYRS) index(mean) nq_gps(3) t_transf(ln) detail
 gpscore postCW victory cycle  unintrvnALL UNfpeaid1 eventno2 prop mixed unexec dcen, t(T2fpeyrs1) gpscore(pscore) predict(hat_treat) sigma(sd) cutpoints(cutYRS) index(mean) nq_gps(2) t_transf(ln) detail
  *same for nq_gps(3) and nq_gps(2)

*DOSERESPONSE FOR TREATMENTS (MONTHS and YEARS)*
drop sd hat_treat pscore
doseresponse postCW victory cycle unintrvnALL UNfpeaid1 eventno2 prop mixed unexec dcen, outcome(nwar1) gpscore(pscore) t(T2fpemths1) predict(hat_treat) sigma(sd) npoints(10) delta(1) cutpoints(cutMTHS) index(mean) nq_gps(3) dose_response(dresp) flag(0) reg_type_t(quadratic) reg_type_gps(quadratic) interaction(1) bootstrap(yes) boot_reps(100) analysis(yes) t_transf(ln) detail filename("/Users/brancati/Documents/Temp/BS09_iDOSERESPONSE_fpepowerOUTPUT.dta")
drop T sd hat_treat pscore broken_*
 doseresponse fpepolity1 postCW victory cycle  unintrvnALL UNfpeaid1 eventno2 prop mixed unexec dcen, outcome(nwar1) gpscore(pscore) t(T2fpeyrs1) predict(hat_treat) sigma(sd) npoints(10) delta(1) cutpoints(cutYRS) index(mean) nq_gps(3) dose_response(dresp) flag(0) reg_type_t(quadratic) reg_type_gps(quadratic) interaction(1) bootstrap(yes) boot_reps(100) analysis(yes) t_transf(ln) detail graph("/Users/brancati/Documents/Temp/fpepowerGPS.gph") filename("/Users/brancati/Documents/Temp/BS09_iDOSERESPONSE_fpepowerOUTPUT.dta")
*The axis,labels, etc. have been edited manually.

*MANUALLY CALCULATE THE (MTHS) REGRESSION (CHECK) [Y = T + T^2 + GPS + GPS^2 + T*GPS]* SEs are not bootstrapped but clustered by countryname*
gen T2fpemths1_sq = T2fpemths1*T2fpemths1
gen pscore_sq = pscore*pscore
gen T2fpemths1_pscore = T2fpemths1*pscore
logit nwar1 T2fpemths1 T2fpemths1_sq pscore pscore_sq T2fpemths1_pscore, cluster(countryname)

*GRAPH OUTCOME USING OUTPUT FILE*
*Figure 2, Graph 1*
use "/Users/brancati/Documents/Working Papers/Active/Election Timing/Analysis/REPLICATION FILES/DATA/BS09_iDOSERESPONSE_fpepowerOUTPUT.dta"
twoway (line dresp treatment_level), ytitle(Probability of New War) ytitle(, size(small) margin(medsmall)) ylabel(, labsize(small)) xtitle(Time to First Post-Conflict Election (Months)) xtitle(, size(small) margin(medsmall)) xlabel(0(5)30, labsize(small)) xmtick(0(5)30, nolabels) 
graph save Graph "/Users/brancati/Documents/Working Papers/Active/Election Timing/Analysis/Graphs/fpepowerGPS.gph", replace


***************************************************************************************************************************************
********************************************* NATIONAL ELECTIONS **********************************************************************
***************************************************************************************************************************************

*************************************************
**GENERATE DATAFILE: BASIC MODEL + POWERSHARING**
*************************************************

*GENERATE DATAFILE: MISSING DATA NOT ALLOWED*
clear
use "/Users/brancati/Documents/Working Papers/Active/Election Timing/Analysis/REPLICATION FILES/DATA/BS09_DATA_main.dta"
keep if nENDinWAR !=1
keep cwid countryname nwar1 T2nemths1 postCW victory cycle  nintvngwar1 unintrvnALL UNneaid1 eventno2 prop mixed unexec dcen 
drop if (T2nemths1 == . | postCW  == . | victory == . | cycle == | .  nintvngwar1 == . | unintrvnALL == . | UNneaid1 == . | eventno2 == .| prop == . | mixed == . | unexec == . | dcen == . )
 *save "/Users/brancati/Documents/Working Papers/Active/Election Timing/Analysis/REPLICATION FILES/DATA/BS09_iDOSERESPONSE_npower.dta", replace

#TEMP: BALANCING NOT BEING ACHIEVED BECAUSE OF T2MTHS NOT BEING ELECTION == 0 IN TWO CASES. MUST REPLACE SO THAT IT IS GREAT THAN 0; LIBERIA END1997 = 0; SOUTH AFRICA 
replace T2nemths1 = .1 if T2nemths1 == 0

*GENERATE CUT VARIABLE BASED ON THE TREATMENT*
sort countryname cwid
 *replace T2nemths1 = 1 if T2nemths1 == 0
 *T2nemths1 equal 0 in a couple of cases, which creates two many broken_pts.
egen cutMTHS = cut(T2nemths1), group(3)

*GENERATE CUT VARIABLE BASED ON THE TREATMENT (YEARS)*
sort countryname cwid
gen T2neyrs1 = T2nemths1/12
 replace T2neyrs1 = 1 if T2neyrs1 == 0
egen cutYRS = cut(T2neyrs1), group(3)

*Note: While fintvngwar1 may be used to predict T2fpemths1, in the second analysis we drop all post-conflict periods for which an election does not not occur before a new civil war occurs. As a result, fintvngwar1 is equal to 0 in all cases. It is not included as a predictor of timing as a result. 
*CALCULATE GPS AND CHECK FOR BALANCE (MONTHS and YEARS)*
 gpscore postCW victory cycle  unintrvnALL UNneaid1 eventno2 prop mixed unexec dcen, t(T2nemths1) gpscore(pscore) predict(hat_treat) sigma(sd) cutpoints(cutMTHS) index(mean) nq_gps(3) t_transf(ln) detail
gpscore postCW victory cycle  unintrvnALL UNneaid1 eventno2 prop mixed unexec dcen, t(T2neyrs1) gpscore(pscore) predict(hat_treat) sigma(sd) cutpoints(cutYRS) index(mean) nq_gps(3) t_transf(ln) detail
   #Satisfying property at .01 is weaker than at .10 level -- for the first (0.01) this means, that the treatment and controls are not significantly different is we use a 99 percent level of significance, but they are significantly different at the 95 percent level. 

*DOSERESPONSE FOR TREATMENTS (MONTHS and YEARS)*
drop sd hat_treat pscore
doseresponse postCW victory cycle  unintrvnALL UNneaid1 eventno2 prop mixed unexec dcen, outcome(nwar1) gpscore(pscore) t(T2nemths1) predict(hat_treat) sigma(sd) npoints(10) delta(1) cutpoints(cutMTHS) index(mean) nq_gps(3) dose_response(dresp) flag(0) reg_type_t(quadratic) reg_type_gps(quadratic) interaction(1) bootstrap(yes) boot_reps(100) analysis(yes) t_transf(ln) detail filename("/Users/brancati/Documents/Temp/BS09_iDOSERESPONSE_npowerOUTPUT.dta")
drop T sd hat_treat pscore broken_*
 doseresponse postCW victory cycle  unintrvnALL UNneaid1 eventno2 prop mixed unexec dcen, outcome(nwar1) gpscore(pscore) t(T2neyrs1) predict(hat_treat) sigma(sd) npoints(10) delta(1) cutpoints(cutYRS) index(mean) nq_gps(3) dose_response(dresp) flag(0) reg_type_t(quadratic) reg_type_gps(quadratic) interaction(1) bootstrap(yes) boot_reps(100) analysis(yes) t_transf(ln) detail graph("/Users/brancati/Documents/Temp/nepowerGPS.gph") filename("/Users/brancati/Documents/Temp/BS09_iDOSERESPONSE_npowerOUTPUT.dta")
*The axis,labels, etc. have been edited manually. 

*MANUALLY CALCULATE THE REGRESSION (CHECK) [Y = T + T^2 + GPS + GPS^2 + T*GPS]*
gen T2nemths1_sq = T2nemths1*T2nemths1
gen pscore_sq = pscore*pscore
gen T2nemths1_pscore = T2nemths1*pscore
logit nwar1 T2nemths1 T2nemths1_sq pscore pscore_sq T2nemths1_pscore, cluster(countryname)

*GRAPH OUTCOME USING OUTPUT FILE*
*Figure 2, Graph 2*
use "/Users/brancati/Documents/Working Papers/Active/Election Timing/Analysis/REPLICATION FILES/DATA/BS09_iDOSERESPONSE_npowerOUTPUT.dta"
twoway (line dresp treatment_level), ytitle(Probability of New War) ytitle(, size(small) margin(medsmall)) ylabel(, labsize(small)) xtitle(Time to First Post-Conflict National Election (Months)) xtitle(, size(small) margin(medsmall)) xlabel(0(5)30, labsize(small)) xmtick(0(5)30, nolabels) 
graph save Graph "/Users/brancati/Documents/Working Papers/Active/Election Timing/Analysis/Graphs/npowerGPS.pdf"


