**********************
**iDOSERESPONSE CODE**
**********************

***************************************************************************************************************************************
********************************************* FIRST POST-CONFLICT ELECTIONS ***********************************************************
**************************************************  ALL ELECTIONS  ********************************************************************
***************************************************************************************************************************************
*Note: The GPS formula is based on the probability density function of the normal distribution (see notes).  
*Note: If data is in years rather than months, predicted _hat treat is different.  GPS is the same, sd2 is the same. 

*****************
***BASIC MODEL*** 
*****************

*GENERATE DATAFILE: MISSING DATA NOT ALLOWED*
clear
use "/Users/brancati/Documents/Working Papers/Active/Election Timing/Analysis/REPLICATION FILES/DATA/BS09_DATA_main.dta"
keep if fENDinWAR !=1
keep cwid countryname nwar1 T2fpemths1 fpepolity1 postCW victory cycle prv10yrs fintvngwar1 unintrvnALL UNfpeaid1 eventno2  
drop if (postCW == . | victory == . | fintvngwar1 == . | cycle == . |  unintrvnALL == . | UNfpeaid1 == . | eventno == . | T2fpemths1 == .)
*save "/Users/brancati/Documents/Working Papers/Active/Election Timing/Analysis/REPLICATION FILES/DATA/ROBUSTNESS DATA FILES/iDOSERESPONSE_fpebase.dta", replace

*GENERATE CUT VARIABLE BASED ON THE TREATMENT (MTHS)*
sort countryname cwid
egen cutMTHS = cut(T2fpemths1), group(3)

*GENERATE CUT VARIABLE BASED ON THE TREATMENT (YEARS)*
sort countryname cwid
gen T2fpeyrs1 = T2fpemths1/12
egen cutYRS = cut(T2fpeyrs1), group(3)

*CALCULATE GPS AND CHECK FOR BALANCE (MONTHS and YEARS)*
gpscore postCW victory cycle  unintrvnALL UNfpeaid1  eventno2, t(T2fpemths1) gpscore(pscore) predict(hat_treat) sigma(sd) cutpoints(cutMTHS) index(mean) nq_gps(3) t_transf(ln) detail
 gpscore postCW victory cycle  unintrvnALL UNfpeaid1 eventno2, t(T2fpeyrs1) gpscore(pscore) predict(hat_treat) sigma(sd) cutpoints(cutYRS) index(mean) nq_gps(3) t_transf(ln) detail
#Satisfying property at .01 is weaker than at .10 level -- for the first (0.01) this means, that the treatment and controls are not significantly different is we use a 99 percent level of significance, but they are significantly different at the 95 percent level. 

*Note: While fintvngwar1 may be used to predict T2fpemths1, in the second analysis we drop all post-conflict periods for which an election does not not occur before a new civil war occurs. As a result, fintvngwar1 is equal to 0 in all cases. It is not included as a predictor of timing as a result. 
*DOSERESPONSE FOR TREATMENTS (MONTHS and YEARS)*
drop T sd hat_treat pscore broken_*
doseresponse postCW victory cycle  unintrvnALL UNfpeaid1 eventno2, outcome(nwar1) gpscore(pscore) t(T2fpemths1) predict(hat_treat) sigma(sd) npoints(10) delta(1) cutpoints(cutMTHS) index(mean) nq_gps(3) dose_response(dresp) flag(0) reg_type_t(quadratic) reg_type_gps(quadratic) interaction(1) bootstrap(yes) boot_reps(100) analysis(yes) t_transf(ln) detail filename("/Users/brancati/Documents/Temp/iDOSERESPONSE_fpebaseOUTPUT.dta")
doseresponse postCW victory cycle  unintrvnALL UNfpeaid1 eventno2, outcome(nwar1) gpscore(pscore) t(T2fpeyrs1) predict(hat_treat) sigma(sd) npoints(10) delta(1) cutpoints(cutYRS) index(mean) nq_gps(3) dose_response(dresp) flag(0) reg_type_t(quadratic) reg_type_gps(quadratic) interaction(1) bootstrap(yes) boot_reps(100) analysis(yes) t_transf(ln) detail filename("/Users/brancati/Documents/Temp/iDOSERESPONSE_fpebaseOUTPUT.dta")

*MANUALLY CALCULATE THE (MTHS) REGRESSION (CHECK) [Y = T + T^2 + GPS + GPS^2 + T*GPS]*
*Using vce(bootknife) does not yield the same SEs as above. 
gen T2fpemths1_sq = T2fpemths1*T2fpemths1
gen pscore_sq = pscore*pscore
gen T2fpemths1_pscore = T2fpemths1*pscore
logit nwar1 T2fpemths1 T2fpemths1_sq pscore pscore_sq T2fpemths1_pscore, cluster(countryname)
 outreg2 
*MERGE WITH FULL DATA TO INCLUDE CONTROLS IN THE MODEL*
merge cwid using "/Users/brancati/Documents/Working Papers/Active/Election Timing/Analysis/REPLICATION FILES/DATA/BS09_DATA_main.dta", sort
logit nwar1 T2fpemths1 T2fpemths1_sq pscore pscore_sq T2fpemths1_pscore nepolity1 postCW victory unintrvnALL UNneaid1 eventno2 if pscore != ., cluster(countryname)
logit nwar1 T2fpemths1 T2fpemths1_sq pscore pscore_sq T2fpemths1_pscore nepolity1 postCW victory unintrvnALL UNneaid1 eventno2 pr  unexec if pscore != ., cluster(countryname)
logit nwar1 T2fpemths1 T2fpemths1_sq pscore pscore_sq T2fpemths1_pscore nepolity1 postCW victory unintrvnALL UNneaid1 eventno2 wardur dead ridp gdpen if pscore != ., cluster(countryname) 

*GRAPH OUTCOME USING OUTPUT FILE*
use "/Users/brancati/Documents/Temp/iDOSERESPONSE_fpebaseOUTPUT.dta"
twoway (line dresp treatment_level), ytitle(Probability of New War) ytitle(, size(small) margin(medsmall)) ylabel(, labsize(small)) xtitle(Time to First Post-Conflict Election (Months)) xtitle(, size(small) margin(medsmall)) ylabel(0(.2)1) xlabel(0(60)420, labsize(small)) xmtick(0(24)420, nolabels) 
 graph save Graph "/Users/brancati/Documents/Working Papers/Active/Election Timing/Analysis/Graphs/fpbaseGPS.gph", replace
 graph save Graph "/Users/brancati/Documents/Working Papers/Active/Election Timing/Analysis/Graphs/fpbaseGPS.pdf", replace

*************************************************
**GENERATE DATAFILE: BASIC MODEL + POWERSHARING**
*************************************************

*GENERATE DATAFILE: MISSING DATA NOT ALLOWED*
clear
use "/Users/brancati/Documents/Working Papers/Active/Election Timing/Analysis/REPLICATION FILES/DATA/BS09_DATA_main.dta"
keep if fENDinWAR !=1
keep cwid countryname nwar1 T2fpemths1 postCW victory cycle  fintvngwar1 unintrvnALL UNfpeaid1 eventno2 prop mixed unexec dcen
drop if (T2fpemths1 == . |  fpepolity1 == . | postCW  == . | victory == . | cycle == . |  fintvngwar1 == . | unintrvnALL == . | UNfpeaid1 == . | eventno2 == .| prop == . | mixed == . | unexec == . | dcen == .)
*save "/Users/brancati/Documents/Working Papers/Active/Election Timing/Analysis/REPLICATION FILES/DATA/BS09_iDOSERESPONSE_fpepower.dta", replace

*GENERATE CUT VARIABLE BASED ON THE TREATMENT*
sort countryname cwid
egen cutMTHS = cut(T2fpemths1), group(3)

*GENERATE CUT VARIABLE BASED ON THE TREATMENT (YEARS)*
sort countryname cwid
gen T2fpeyrs1 = T2fpemths1/12
egen cutYRS = cut(T2fpeyrs1), group(3)

*Note: While fintvngwar1 may be used to predict T2fpemths1, in the second analysis we drop all post-conflict periods for which an election does not not occur before a new civil war occurs. As a result, fintvngwar1 is equal to 0 in all cases. It is not included as a predictor of timing as a result. 
*CALCULATE GPS AND CHECK FOR BALANCE (MONTHS and YEARS)*
gpscore postCW victory cycle  unintrvnALL UNfpeaid1 eventno2 prop mixed unexec dcen, t(T2fpemths1) gpscore(pscore) predict(hat_treat) sigma(sd) cutpoints(cutMTHS) index(mean) nq_gps(3) t_transf(ln) detail
 gpscore postCW victory cycle  unintrvnALL UNfpeaid1 eventno2 prop mixed unexec dcen, t(T2fpeyrs1) gpscore(pscore) predict(hat_treat) sigma(sd) cutpoints(cutYRS) index(mean) nq_gps(3) t_transf(ln) detail
 #Satisfying property at .01 is weaker than at .10 level -- for the first (0.01) this means, that the treatment and controls are not significantly different is we use a 99 percent level of significance, but they are significantly different at the 95 percent level. 

 
Note:Balancing is satisfied at a higher level with different treatment groups. 
sort countryname cwid
gen T2fpeyrs1 = T2fpemths1/12
egen cutYRS = cut(T2fpeyrs1), group(2)
 gpscore postCW victory cycle  unintrvnALL UNfpeaid1 eventno2 prop mixed unexec dcen, t(T2fpeyrs1) gpscore(pscore) predict(hat_treat) sigma(sd) cutpoints(cutYRS) index(mean) nq_gps(3) t_transf(ln) detail
 gpscore postCW victory cycle  unintrvnALL UNfpeaid1 eventno2 prop mixed unexec dcen, t(T2fpeyrs1) gpscore(pscore) predict(hat_treat) sigma(sd) cutpoints(cutYRS) index(mean) nq_gps(2) t_transf(ln) detail
  *same for nq_gps(3) and nq_gps(2)
  
***********************
**** PAPER MODELS *****  
***********************
*DOSERESPONSE FOR TREATMENTS (MONTHS and YEARS)*
drop T sd hat_treat pscore broken_*
 doseresponse postCW victory cycle  unintrvnALL UNfpeaid1 eventno2 prop mixed unexec dcen, outcome(nwar1) gpscore(pscore) t(T2nemths1) predict(hat_treat) sigma(sd) npoints(10) delta(1) cutpoints(cutMTHS) index(mean) nq_gps(3) dose_response(dresp) flag(0) reg_type_t(quadratic) reg_type_gps(quadratic) interaction(1) bootstrap(yes) boot_reps(100) analysis(yes) t_transf(ln) detail filename("/Users/brancati/Documents/Temp/iDOSERESPONSE_fpepowerOUTPUT.dta")
 *doseresponse postCW victory cycle  unintrvnALL UNfpeaid1 eventno2 prop mixed unexec dcen, outcome(nwar1) gpscore(pscore) t(T2fpeyrs1) predict(hat_treat) sigma(sd) npoints(10) delta(1) cutpoints(cutYRS) index(mean) nq_gps(3) dose_response(dresp) flag(0) reg_type_t(quadratic) reg_type_gps(quadratic) interaction(1) bootstrap(yes) boot_reps(100) analysis(yes) t_transf(ln) detail graph("/Users/brancati/Documents/Temp/fpepowerGPS.gph") filename("/Users/brancati/Documents/Temp/iDOSERESPONSE_fpepowerOUTPUT.dta")

*MANUALLY CALCULATE THE (MTHS) REGRESSION (CHECK) [Y = T + T^2 + GPS + GPS^2 + T*GPS]* SEs are not bootstrapped by clustered by countryname*
gen T2fpemths1_sq = T2fpemths1*T2fpemths1
gen pscore_sq = pscore*pscore
gen T2fpemths1_pscore = T2fpemths1*pscore
logit nwar1 T2fpemths1 T2fpemths1_sq pscore pscore_sq T2fpemths1_pscore, cluster(countryname)

*MERGE WITH FULL DATA TO INCLUDE CONTROLS IN THE MODEL*
merge cwid using "/Users/brancati/Documents/Working Papers/Active/Election Timing/Analysis/REPLICATION FILES/BS09_DATA.dta", sort
logit nwar1 T2nemths1 T2nemths1_sq pscore pscore_sq T2nemths1_pscore postCW victory unintrvnALL UNneaid1 eventno2 if pscore != ., cluster(countryname)
logit nwar1 T2nemths1 T2nemths1_sq pscore pscore_sq T2nemths1_pscore postCW victory unintrvnALL UNneaid1 eventno2 pr mixed unexec if pscore != ., cluster(countryname)
logit nwar1 T2nemths1 T2nemths1_sq pscore pscore_sq T2nemths1_pscore postCW victory unintrvnALL UNneaid1 eventno2 wardur dead ridp gdpen if pscore != ., cluster(countryname) 

*GRAPH OUTCOME USING OUTPUT FILE*
use "/Users/brancati/Documents/Temp/iDOSERESPONSE_fpepowerOUTPUT.dta"
twoway (line dresp treatment_level), ytitle(Probability of New War) ytitle(, size(small) margin(medsmall)) ylabel(, labsize(small)) xtitle(Time to First Post-Conflict Election (Months)) xtitle(, size(small) margin(medsmall)) xlabel(0(60)420, labsize(small)) xmtick(0(24)420, nolabels) 
graph save Graph "/Users/brancati/Documents/Working Papers/Active/Election Timing/Analysis/Graphs/fpepowerGPS.gph", replace


*********************************
**GENERATE DATAFILE: FULL MODEL**
*********************************

*GENERATE DATAFILE: MISSING DATA NOT ALLOWED*
clear
use "/Users/brancati/Documents/Working Papers/Active/Election Timing/Analysis/REPLICATION FILES/DATA/BS09_DATA_main.dta"
keep if fENDinWAR !=1
keep cwid countryname nwar1 T2fpemths1 postCW victory cycle fintvngwar1 unintrvnALL UNfpeaid1 eventno2 prop mixed unexec dcen wardur dead ridp gdpen 
drop if (T2fpemths1 == . |  postCW  == . | victory == . | cycle == . |  fintvngwar1 == . | unintrvnALL == . | UNfpeaid1 == . | eventno2 == .| prop == . | mixed == . | unexec == . | dcen == . | wardur == . | dead == . | ridp == . | gdpen == .)
*save "/Users/brancati/Documents/Working Papers/Active/Election Timing/Analysis/REPLICATION FILES/DATA/ROBUSTNESS DATA FILES/iDOSERESPONSE_fpefull.dta"

*GENERATE CUT VARIABLE BASED ON THE TREATMENT*
sort countryname cwid
egen cutMTHS = cut(T2nemths1), group(3)

*GENERATE CUT VARIABLE BASED ON THE TREATMENT (YEARS)*
sort countryname cwid
gen T2fpeyrs1 = T2fpemths1/12
egen cutYRS = cut(T2fpeyrs1), group(3)

*Note: While fintvngwar1 may be used to predict T2fpemths1, in the second analysis we drop all post-conflict periods for which an election does not not occur before a new civil war occurs. As a result, fintvngwar1 is equal to 0 in all cases. It is not included as a predictor of timing as a result. 
*CALCULATE GPS AND CHECK FOR BALANCE (MONTHS and YEARS)*
gpscore postCW victory cycle  unintrvnALL UNfpeaid1 eventno2 prop mixed unexec dcen wardur dead ridp gdpen, t(T2fpemths1) gpscore(pscore) predict(hat_treat) sigma(sd) cutpoints(cutMTHS) index(mean) nq_gps(3) t_transf(ln) detail
 gpscore postCW victory cycle  unintrvnALL UNfpeaid1 eventno2 prop mixed unexec dcen wardur dead ridp gdpen, t(T2fpeyrs1) gpscore(pscore) predict(hat_treat) sigma(sd) cutpoints(cutYRS) index(mean) nq_gps(3) t_transf(ln) detail
  #Satisfying property at .01 is weaker than at .10 level -- for the first (0.01) this means, that the treatment and controls are not significantly different is we use a 99 percent level of significance, but they are significantly different at the 95 percent level. 

*DOSERESPONSE FOR TREATMENTS (MONTHS and YEARS)*
drop T sd hat_treat pscore broken_*
doseresponse postCW victory cycle  unintrvnALL UNfpeaid1 eventno2 prop mixed unexec dcen wardur dead ridp gdpen, outcome(nwar1) gpscore(pscore) t(T2nemths1) predict(hat_treat) sigma(sd) npoints(10) delta(1) cutpoints(cutMTHS) index(mean) nq_gps(3) dose_response(dresp) flag(0) reg_type_t(quadratic) reg_type_gps(quadratic) interaction(1) bootstrap(yes) boot_reps(100) analysis(yes) t_transf(ln) detail filename("/Users/brancati/Documents/Temp/iDOSERESPONSE_fpefullOUTPUT.dta")
  doseresponse postCW victory cycle  unintrvnALL UNfpeaid1 eventno2 prop mixed unexec dcen wardur dead ridp gdpen, outcome(nwar1) gpscore(pscore) t(T2nemths1) predict(hat_treat) sigma(sd) npoints(10) delta(1) cutpoints(cutYRS) index(mean) nq_gps(3) dose_response(dresp) flag(0) reg_type_t(quadratic) reg_type_gps(quadratic) interaction(1) bootstrap(yes) boot_reps(100) analysis(yes) t_transf(ln) detail filename("/Users/brancati/Documents/Temp/iDOSERESPONSE_fpefullOUTPUT.dta")

*MANUALLY CALCULATE THE REGRESSION (CHECK) [Y = T + T^2 + GPS + GPS^2 + T*GPS]*
gen T2fpemths1_sq = T2fpemths1*T2fpemths1
gen pscore_sq = pscore*pscore
gen T2fpemths1_pscore = T2fpemths1*pscore
logit nwar1 T2fpemths1 T2fpemths1_sq pscore pscore_sq T2fpemths1_pscore, cluster(countryname)

*MERGE WITH FULL DATA TO INCLUDE CONTROLS IN THE MODEL*
merge cwid using "/Users/brancati/Documents/Working Papers/Active/Election Timing/Analysis/REPLICATION FILES/BS09_DATA.dta", sort
logit nwar1 T2nemths1 T2nemths1_sq pscore pscore_sq T2nemths1_pscore postCW victory unintrvnALL UNneaid1 eventno2 if pscore != ., cluster(countryname)
logit nwar1 T2nemths1 T2nemths1_sq pscore pscore_sq T2nemths1_pscore postCW victory unintrvnALL UNneaid1 eventno2 pr mixed unexec dcenEVR1 if pscore != ., cluster(countryname)
logit nwar1 T2nemths1 T2nemths1_sq pscore pscore_sq T2nemths1_pscore postCW victory unintrvnALL UNneaid1 eventno2 wardur dead ridp gdpen if pscore != ., cluster(countryname) 

*GRAPH OUTCOME USING OUTPUT FILE*
use "/Users/brancati/Documents/Temp/iDOSERESPONSE_fpefullOUTPUT.dta"
twoway (line dresp treatment_level), ytitle(Probability of New War) ytitle(, size(small) margin(medsmall)) ylabel(, labsize(small)) xtitle(Time to First Post-Conflict Election (Months)) xtitle(, size(small) margin(medsmall)) xlabel(0(60)420, labsize(small)) xmtick(0(24)420, nolabels) 
graph save Graph "/Users/brancati/Documents/Working Papers/Active/Election Timing/Analysis/Graphs/fpefullGPS.pdf", replace

 
***************************************************************************************************************************************
********************************************* NATIONAL ELECTIONS **********************************************************************
***************************************************************************************************************************************

*****************
***BASIC MODEL*** 
*****************

*GENERATE DATAFILE: MISSING DATA NOT ALLOWED*
clear
use "/Users/brancati/Documents/Working Papers/Active/Election Timing/Analysis/REPLICATION FILES/DATA/BS09_DATA_main.dta"
keep if nENDinWAR !=1
keep cwid countryname nwar1 T2nemths1 postCW victory cycle nintvngwar1 unintrvnALL UNneaid1 eventno2 
drop if (T2nemths1 == . | nepolity == . | postCW == . | victory == . | nintvngwar1 == . | cycle == . |  =. | unintrvnALL == . | UNneaid1 == . | eventno == . )
*save "/Users/brancati/Documents/Working Papers/Active/Election Timing/Analysis/REPLICATION FILES/DATA/ROBUSTNESS DATA FILES/iDOSERESPONSE_nbase.dta", replace

*GENERATE CUT VARIABLE BASED ON THE TREATMENT (MTHS)*
sort countryname cwid
 *replace T2nemths1 = 1 if T2nemths1 == 0
 *T2nemths1 equal 0 in a couple of cases, which creates two many broken_pts.
egen cutMTHS = cut(T2nemths1), group(3)

*GENERATE CUT VARIABLE BASED ON THE TREATMENT (YEARS)*
sort countryname cwid
gen T2neyrs1 = T2nemths1/12
 replace T2neyrs1 = 1 if T2neyrs1 == 0
egen cutYRS = cut(T2neyrs1), group(3)

*Note: While fintvngwar1 may be used to predict T2fpemths1, in the second analysis we drop all post-conflict periods for which an election does not not occur before a new civil war occurs. As a result, fintvngwar1 is equal to 0 in all cases. It is not included as a predictor of timing as a result. 
*CALCULATE GPS AND CHECK FOR BALANCE (MONTHS and YEARS)*
gpscore postCW victory cycle   unintrvnALL UNneaid1 eventno2, t(T2nemths1) gpscore(pscore) predict(hat_treat) sigma(sd) cutpoints(cutMTHS) index(mean) nq_gps(3) t_transf(ln) detail
 gpscore postCW victory cycle  unintrvnALL UNneaid1 eventno2, t(T2neyrs1) gpscore(pscore) predict(hat_treat) sigma(sd) cutpoints(cutYRS) index(mean) nq_gps(3) t_transf(ln) detail
 gpscore postCW victory cycle  unintrvnALL UNneaid1 eventno2, t(T2neyrs1) gpscore(pscore) predict(hat_treat) sigma(sd) cutpoints(cutYRS) index(mean) nq_gps(2) t_transf(ln) test (Bayes_factor) detail
 #Satisfying property at .01 is weaker than at .10 level -- for the first (0.01) this means, that the treatment and controls are not significantly different is we use a 99 percent level of significance, but they are significantly different at the 95 percent level. 

*DOSERESPONSE FOR TREATMENTS (MONTHS and YEARS)*
drop T sd hat_treat pscore broken_*
doseresponse postCW victory cycle  unintrvnALL UNneaid1 eventno2, outcome(nwar1) gpscore(pscore) t(T2nemths1) predict(hat_treat) sigma(sd) npoints(10) delta(1) cutpoints(cutMTHS) index(mean) nq_gps(3) dose_response(dresp) flag(0) reg_type_t(quadratic) reg_type_gps(quadratic) interaction(1) bootstrap(yes) boot_reps(100) analysis(yes) t_transf(ln) detail filename("/Users/brancati/Documents/Temp/iDOSERESPONSE_nbaseOUTPUT.dta")
 doseresponse postCW victory cycle  unintrvnALL UNneaid1 eventno2, outcome(nwar1) gpscore(pscore) t(T2neyrs1) predict(hat_treat) sigma(sd) npoints(10) delta(1) cutpoints(cutYRS) index(mean) nq_gps(3) dose_response(dresp) flag(1) reg_type_t(quadratic) reg_type_gps(quadratic) interaction(1) bootstrap(yes) boot_reps(100) analysis(yes) t_transf(ln) detail filename("/Users/brancati/Documents/Temp/iDOSERESPONSE_nbaseOUTPUT.dta")

*MANUALLY CALCULATE THE (MTHS) REGRESSION (CHECK) [Y = T + T^2 + GPS + GPS^2 + T*GPS]*
gen T2nemths1_sq = T2nemths1*T2nemths1
gen pscore_sq = pscore*pscore
gen T2nemths1_pscore = T2nemths1*pscore
logit nwar1 T2nemths1 T2nemths1_sq pscore pscore_sq T2nemths1_pscore, cluster(countryname)
 outreg 

*MERGE WITH FULL DATA (MTHS) TO INCLUDE CONTROLS IN THE MODEL*
merge cwid using "/Users/brancati/Documents/Working Papers/Active/Election Timing/Analysis/REPLICATION FILES/BS09_DATA.dta", sort
logit nwar1 T2nemths1 T2nemths1_sq pscore pscore_sq T2nemths1_pscore postCW victory unintrvnALL UNneaid1 eventno2 if pscore != ., cluster(countryname)
logit nwar1 T2nemths1 T2nemths1_sq pscore pscore_sq T2nemths1_pscore postCW victory unintrvnALL UNneaid1 eventno2 pr mixed unexec dcenEVR1 if pscore != ., cluster(countryname)
logit nwar1 T2nemths1 T2nemths1_sq pscore pscore_sq T2nemths1_pscore postCW victory unintrvnALL UNneaid1 eventno2 wardur dead ridp gdpen if pscore != ., cluster(countryname) 

*GRAPH OUTCOME USING OUTPUT FILE*
use "/Users/brancati/Documents/Temp/iDOSERESPONSE_nbaseOUTPUT.dta"
twoway (line dresp treatment_level), ytitle(Probability of New War) ytitle(, size(small) margin(medsmall)) ylabel(, labsize(small)) xtitle(Time to First Post-Conflict National Election (Months)) xtitle(, size(small) margin(medsmall)) ylabel(0(.2)1) xlabel(0(60)420, labsize(small)) xmtick(0(24)420, nolabels) 
graph save Graph "/Users/brancati/Documents/Working Papers/Active/Election Timing/Analysis/Graphs/nbaseGPS.gph", replace
graph save Graph "/Users/brancati/Documents/Working Papers/Active/Election Timing/Analysis/Graphs/nbaseGPS.pdf", replace
 *Two graphs side by side*
 graph combine "/Users/brancati/Documents/Working Papers/Active/Election Timing/Analysis/Graphs/nbaseGPS.gph" "/Users/brancati/Documents/Working Papers/Active/Election Timing/Analysis/Graphs/fpbaseGPS.gph"
 *Two graphs overlayed on top of each other*
  use "/Users/brancati/Documents/Temp/iDOSERESPONSE_fpebaseOUTPUT.dta"
  egen seq = seq(), from(1) to(11)
  save "/Users/brancati/Documents/Temp/iDOSERESPONSE_fpebaseOUTPUT.dta", replace
 
  use "/Users/brancati/Documents/Temp/iDOSERESPONSE_nbaseOUTPUT.dta"
  egen seq = seq(), from(12) to(23)
  save "/Users/brancati/Documents/Temp/iDOSERESPONSE_nbaseOUTPUT.dta", replace
  
  use "/Users/brancati/Documents/Temp/iDOSERESPONSE_fpebaseOUTPUT.dta"
  merge seq using "/Users/brancati/Documents/Temp/iDOSERESPONSE_nbaseOUTPUT.dta", sort
  gen treatment_level2 = treatment_level if _merge == 2 
  replace treatment_level = . if _merge == 2
  gen dresp2 = dresp if _merge == 2 
  replace dresp = . if _merge == 2
  
  twoway (line dresp treatment_level, lpattern(shortdash)) (line dresp2 treatment_level2,  lpattern(solid)), ytitle(Probability of New War) ytitle(, size(small) margin(medsmall)) ylabel(, labsize(small)) xtitle(Time to First Post-Conflict Election (Months)) xtitle(, size(small) margin(medsmall)) ylabel(0(.2)1) xlabel(0(60)420, labsize(small)) xmtick(0(24)420, nolabels) legend(order(1 "All Elections" 2 "National Elections") nostack size(small) position(1) ring(0))
  graph save Graph "/Users/brancati/Documents/Working Papers/Active/Election Timing/Analysis/Graphs/fpe_nbaseGPS.gph", replace

  
*************************************************
**GENERATE DATAFILE: BASIC MODEL + POWERSHARING**
*************************************************

*GENERATE DATAFILE: MISSING DATA NOT ALLOWED*
clear
use "/Users/brancati/Documents/Working Papers/Active/Election Timing/Analysis/REPLICATION FILES/DATA/BS09_DATA_main.dta"
keep if nENDinWAR !=1
keep cwid countryname nwar1 T2nemths1 postCW victory cycle nintvngwar1 unintrvnALL UNneaid1 eventno2 prop mixed unexec  dcen 
drop if (T2nemths1 == . |  postCW  == . | victory == . | cycle == . |  nintvngwar1 == . | unintrvnALL == . | UNneaid1 == . | eventno2 == .| prop == . | mixed == . | unexec == . | dcen == . )
save "/Users/brancati/Documents/Working Papers/Active/Election Timing/Analysis/REPLICATION FILES/DATA/BS09_iDOSERESPONSE_npower.dta", replace

#TEMP: BALANCING NOT BEING ACHIEVED BECAUSE OF T2MTHS NOT BEING ELECTION == 0 IN TWO CASES. MUST REPLACE SO THAT IT IS GREAT THAN 0; LIBERIA END1997 = 0; SOUTH AFRICA 
replace T2nemths1 = .1 if T2nemths1 == 0

*GENERATE CUT VARIABLE BASED ON THE TREATMENT*
sort countryname cwid
 *replace T2nemths1 = 1 if T2nemths1 == 0
 *T2nemths1 equal 0 in a couple of cases, which creates two many broken_pts.
egen cutMTHS = cut(T2nemths1), group(3)

*GENERATE CUT VARIABLE BASED ON THE TREATMENT (YEARS)*
sort countryname cwid
gen T2neyrs1 = T2nemths1/12
 replace T2neyrs1 = 1 if T2neyrs1 == 0
egen cutYRS = cut(T2neyrs1), group(3)

*Note: While fintvngwar1 may be used to predict T2fpemths1, in the second analysis we drop all post-conflict periods for which an election does not not occur before a new civil war occurs. As a result, fintvngwar1 is equal to 0 in all cases. It is not included as a predictor of timing as a result. 
*CALCULATE GPS AND CHECK FOR BALANCE (MONTHS and YEARS)*
gpscore postCW victory cycle  unintrvnALL UNneaid1 eventno2 prop mixed unexec dcen, t(T2nemths1) gpscore(pscore) predict(hat_treat) sigma(sd) cutpoints(cutMTHS) index(mean) nq_gps(3) t_transf(ln) detail
  gpscore postCW victory cycle  unintrvnALL UNneaid1 eventno2 prop mixed unexec dcen, t(T2neyrs1) gpscore(pscore) predict(hat_treat) sigma(sd) cutpoints(cutYRS) index(mean) nq_gps(3) t_transf(ln) detail
   #Satisfying property at .01 is weaker than at .10 level -- for the first (0.01) this means, that the treatment and controls are not significantly different is we use a 99 percent level of significance, but they are significantly different at the 95 percent level. 

***********************
**** PAPER MODELS *****  
***********************
*DOSERESPONSE FOR TREATMENTS (MONTHS and YEARS)*
drop T sd hat_treat pscore broken_*
doseresponse postCW victory cycle  unintrvnALL UNneaid1 eventno2 prop mixed unexec dcen, outcome(nwar1) gpscore(pscore) t(T2nemths1) predict(hat_treat) sigma(sd) npoints(10) delta(1) cutpoints(cutMTHS) index(mean) nq_gps(3) dose_response(dresp) flag(0) reg_type_t(quadratic) reg_type_gps(quadratic) interaction(1) bootstrap(yes) boot_reps(100) analysis(yes) t_transf(ln) detail filename("/Users/brancati/Documents/Temp/iDOSERESPONSE_npowerOUTPUT.dta")
 doseresponse postCW victory cycle  unintrvnALL UNneaid1 eventno2 prop mixed unexec dcen, outcome(nwar1) gpscore(pscore) t(T2neyrs1) predict(hat_treat) sigma(sd) npoints(10) delta(1) cutpoints(cutYRS) index(mean) nq_gps(3) dose_response(dresp) flag(0) reg_type_t(quadratic) reg_type_gps(quadratic) interaction(1) bootstrap(yes) boot_reps(100) analysis(yes) t_transf(ln) detail graph("/Users/brancati/Documents/Temp/nepowerGPS.gph") filename("/Users/brancati/Documents/Temp/iDOSERESPONSE_npowerOUTPUT.dta")

*MANUALLY CALCULATE THE REGRESSION (CHECK) [Y = T + T^2 + GPS + GPS^2 + T*GPS]*
gen T2nemths1_sq = T2nemths1*T2nemths1
gen pscore_sq = pscore*pscore
gen T2nemths1_pscore = T2nemths1*pscore
logit nwar1 T2nemths1 T2nemths1_sq pscore pscore_sq T2nemths1_pscore, cluster(countryname)

*MERGE WITH FULL (MTHS) DATA TO INCLUDE CONTROLS IN THE MODEL*
merge cwid using "/Users/brancati/Documents/Working Papers/Active/Election Timing/Analysis/REPLICATION FILES/DATA/BS09_DATA_main.dta", sort
logit nwar1 T2nemths1 T2nemths1_sq pscore pscore_sq T2nemths1_pscore postCW victory unintrvnALL UNneaid1 eventno2 if pscore != ., cluster(countryname)
logit nwar1 T2nemths1 T2nemths1_sq pscore pscore_sq T2nemths1_pscore postCW victory unintrvnALL UNneaid1 eventno2 pr mixed unexec dcenEVR1 if pscore != ., cluster(countryname)
logit nwar1 T2nemths1 T2nemths1_sq pscore pscore_sq T2nemths1_pscore postCW victory unintrvnALL UNneaid1 eventno2 wardur dead ridp gdpen if pscore != ., cluster(countryname) 

*GRAPH OUTCOME USING OUTPUT FILE*
use "/Users/brancati/Documents/Temp/iDOSERESPONSE_npowerOUTPUT.dta"
twoway (line dresp treatment_level), ytitle(Probability of New War) ytitle(, size(small) margin(medsmall)) ylabel(, labsize(small)) xtitle(Time to First Post-Conflict National Election (Months)) xtitle(, size(small) margin(medsmall)) xlabel(0(60)420, labsize(small)) xmtick(0(24)420, nolabels) 
graph save Graph "/Users/brancati/Documents/Working Papers/Active/Election Timing/Analysis/Graphs/npowerGPS.pdf"

*Two graphs side by side*
 graph combine "/Users/brancati/Documents/Working Papers/Active/Election Timing/Analysis/Graphs/npowerGPS.gph" "/Users/brancati/Documents/Working Papers/Active/Election Timing/Analysis/Graphs/fpepowerGPS.gph"
 *Two graphs overlayed on top of each other*
  use "/Users/brancati/Documents/Temp/iDOSERESPONSE_fpepowerOUTPUT.dta"
  egen seq = seq(), from(1) to(11)
  save "/Users/brancati/Documents/Temp/iDOSERESPONSE_fpepowerOUTPUT.dta", replace
 
  use "/Users/brancati/Documents/Temp/iDOSERESPONSE_npowerOUTPUT.dta"
  egen seq = seq(), from(12) to(23)
  save "/Users/brancati/Documents/Temp/iDOSERESPONSE_npowerOUTPUT.dta", replace
  
  use "/Users/brancati/Documents/Temp/iDOSERESPONSE_fpepowerOUTPUT.dta"
  merge seq using "/Users/brancati/Documents/Temp/iDOSERESPONSE_npowerOUTPUT.dta", sort
  gen treatment_level2 = treatment_level if _merge == 2 
  replace treatment_level = . if _merge == 2
  gen dresp2 = dresp if _merge == 2 
  replace dresp = . if _merge == 2
  
  twoway (line dresp treatment_level, lpattern(shortdash)) (line dresp2 treatment_level2,  lpattern(solid)), ytitle(Probability of New War) ytitle(, size(small) margin(medsmall)) ylabel(, labsize(small)) xtitle(Time to First Post-Conflict Election (Months)) xtitle(, size(small) margin(medsmall)) ylabel(0(.2)1) xlabel(0(60)420, labsize(small)) xmtick(0(24)420, nolabels) legend(order(1 "All Elections" 2 "National Elections") nostack size(small) position(1) ring(0))
  graph save Graph "/Users/brancati/Documents/Working Papers/Active/Election Timing/Analysis/Graphs/fpe_nbaseGPS.gph", replace

  
*********************************
**GENERATE DATAFILE: FULL MODEL**
*********************************

*GENERATE DATAFILE: MISSING DATA NOT ALLOWED*
clear
use "/Users/brancati/Documents/Working Papers/Active/Election Timing/Analysis/REPLICATION FILES/DATA/BS09_DATA_main.dta"
keep if nENDinWAR !=1
keep cwid countryname nwar1 T2nemths1 postCW victory cycle nintvngwar1 unintrvnALL UNneaid1 eventno2 prop mixed unexec dcen wardur dead ridp gdpen 
drop if (T2nemths1 == . |  postCW  == . | victory == . | cycle == . | nintvngwar1 == . | unintrvnALL == . | UNneaid1 == . | eventno2 == .| prop == . | mixed == . | unexec == . | dcen == . | wardur == . | dead == . | ridp == . | gdpen == .)
*save "/Users/brancati/Documents/Working Papers/Active/Election Timing/Analysis/REPLICATION FILES/DATA/ROBUSTNESS DATA FILES/iDOSERESPONSE_nfull.dta"

#TEMP: BALANCING NOT BEING ACHIEVED BECAUSE OF T2MTHS NOT BEING ELECTION == 0 IN TWO CASES. MUST REPLACE SO THAT IT IS GREAT THAN 0; LIBERIA END1997 = 0; SOUTH AFRICA 
replace T2nemths1 = .1 if T2nemths1 == 0

*GENERATE CUT VARIABLE BASED ON THE TREATMENT*
sort countryname cwid
 *replace T2nemths1 = 1 if T2nemths1 == 0
 *T2nemths1 equal 0 in a couple of cases, which creates two many broken_pts.
egen cutMTHS = cut(T2nemths1), group(3)

*GENERATE CUT VARIABLE BASED ON THE TREATMENT (YEARS)*
sort countryname cwid
gen T2neyrs1 = T2nemths1/12
 replace T2neyrs1 = 1 if T2neyrs1 == 0
egen cutYRS = cut(T2neyrs1), group(3)

*Note: While fintvngwar1 may be used to predict T2fpemths1, in the second analysis we drop all post-conflict periods for which an election does not not occur before a new civil war occurs. As a result, fintvngwar1 is equal to 0 in all cases. It is not included as a predictor of timing as a result. 
*CALCULATE GPS AND CHECK FOR BALANCE (MONTHS and YEARS)*
gpscore postCW victory cycle unintrvnALL UNneaid1 eventno2 prop mixed unexec dcen wardur dead ridp gdpen, t(T2nemths1) gpscore(pscore) predict(hat_treat) sigma(sd) cutpoints(cutMTHS) index(mean) nq_gps(3) t_transf(ln) detail
 gpscore postCW victory cycle unintrvnALL UNneaid1 eventno2 prop mixed unexec dcen wardur dead ridp gdpen, t(T2neyrs1) gpscore(pscore) predict(hat_treat) sigma(sd) cutpoints(cutYRS) index(mean) nq_gps(3) t_transf(ln) detail
 *Balancing is satisfied if use 2 intervals rather than 3 for cutpoints
  gpscore postCW victory cycle  unintrvnALL UNneaid1 eventno2 prop mixed unexec dcen wardur dead ridp gdpen, t(T2neyrs1) gpscore(pscore) predict(hat_treat) sigma(sd) cutpoints(cutYRS) index(mean) nq_gps(2) t_transf(ln) detail
  #Satisfying property at .01 is weaker than at .10 level -- for the first (0.01) this means, that the treatment and controls are not significantly different is we use a 99 percent level of significance, but they are significantly different at the 95 percent level. 

*DOSERESPONSE FOR TREATMENTS (MONTHS and YEARS)*
drop T sd hat_treat pscore broken_*
doseresponse postCW victory cycle  fintvngwar1 unintrvnALL UNneaid1 eventno2 prop mixed unexec dcen wardur dead ridp gdpen, outcome(nwar1) gpscore(pscore) t(T2nemths1) predict(hat_treat) sigma(sd) npoints(10) delta(1) cutpoints(cutMTHS) index(mean) nq_gps(3) dose_response(dresp) flag(0) reg_type_t(quadratic) reg_type_gps(quadratic) interaction(1) bootstrap(yes) boot_reps(100) analysis(yes) t_transf(ln) detail filename("/Users/brancati/Documents/Temp/iDOSERESPONSE_nfullOUTPUT.dta")
 doseresponse postCW victory cycle  fintvngwar1 unintrvnALL UNneaid1 eventno2 prop mixed unexec dcen wardur dead ridp gdpen, outcome(nwar1) gpscore(pscore) t(T2neyrs1) predict(hat_treat) sigma(sd) npoints(10) delta(1) cutpoints(cutYRS) index(mean) nq_gps(3) dose_response(dresp) flag(0) reg_type_t(quadratic) reg_type_gps(quadratic) interaction(1) bootstrap(yes) boot_reps(100) analysis(yes) t_transf(ln) detail filename("/Users/brancati/Documents/Temp/iDOSERESPONSE_nfullOUTPUT.dta")

*GRAPH OUTCOME USING OUTPUT FILE*
use "/Users/brancati/Documents/Temp/iDOSERESPONSE_nfullOUTPUT.dta"
twoway (line dresp treatment_level), ytitle(Probability of New War) ytitle(, size(small) margin(medsmall)) ylabel(, labsize(small)) xtitle(Time to First Post-Conflict National Election (Months)) xtitle(, size(small) margin(medsmall)) xlabel(0(60)420, labsize(small)) xmtick(0(24)420, nolabels) 
graph save Graph "/Users/brancati/Documents/Working Papers/Active/Election Timing/Analysis/Graphs/nfullGPS.pdf"

